/* Notification.c generated by valac 0.56.19, the Vala compiler
 * generated from Notification.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libsoup/soup.h>
#include <adwaita.h>
#include <glib/gi18n-lib.h>
#include <pango/pango.h>

#define TUBA_INSTANCE_ACCOUNT_KIND_SEVERED_RELATIONSHIPS "severed_relationships"
#define TUBA_INSTANCE_ACCOUNT_KIND_MODERATION_WARNING "moderation_warning"
#define TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_REPORT "admin.report"
#define TUBA_INSTANCE_ACCOUNT_KIND_ANNUAL_REPORT "annual_report"
#define TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_ADDED "added_to_collection"
#define TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_EDITED "collection_update"
#define TUBA_INSTANCE_ACCOUNT_KIND_MENTION "mention"
#define TUBA_INSTANCE_ACCOUNT_KIND_REBLOG "reblog"
#define TUBA_INSTANCE_ACCOUNT_KIND_FAVOURITE "favourite"
#define TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW "follow"
#define TUBA_INSTANCE_ACCOUNT_KIND_POLL "poll"
#define TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST "follow_request"
#define TUBA_INSTANCE_ACCOUNT_KIND_REMOTE_REBLOG "__remote-reblog"
#define TUBA_INSTANCE_ACCOUNT_KIND_EDITED "update"
#define TUBA_INSTANCE_ACCOUNT_KIND_REPLY "tuba_reply"
#define TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP "admin.sign_up"
#define TUBA_INSTANCE_ACCOUNT_KIND_STATUS "status"
#define TUBA_INSTANCE_ACCOUNT_KIND_PLEROMA_REACTION "pleroma:emoji_reaction"
#define TUBA_INSTANCE_ACCOUNT_KIND_REACTION "reaction"
#define TUBA_INSTANCE_ACCOUNT_KIND_QUOTE "quote"
#define TUBA_INSTANCE_ACCOUNT_KIND_QUOTE_UPDATE "quoted_update"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_NOTIFICATION (tuba_api_notification_get_type ())
#define TUBA_API_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotification))
#define TUBA_API_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))
#define TUBA_API_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))

typedef struct _TubaAPINotification TubaAPINotification;
typedef struct _TubaAPINotificationClass TubaAPINotificationClass;
typedef struct _TubaAPINotificationPrivate TubaAPINotificationPrivate;

#define TUBA_API_TYPE_STATUS (tuba_api_status_get_type ())
#define TUBA_API_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatus))
#define TUBA_API_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))
#define TUBA_API_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_STATUS))
#define TUBA_API_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_STATUS))
#define TUBA_API_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))

typedef struct _TubaAPIStatus TubaAPIStatus;
typedef struct _TubaAPIStatusClass TubaAPIStatusClass;

#define TUBA_API_ADMIN_TYPE_REPORT (tuba_api_admin_report_get_type ())
#define TUBA_API_ADMIN_REPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReport))
#define TUBA_API_ADMIN_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReportClass))
#define TUBA_API_ADMIN_IS_REPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_REPORT))
#define TUBA_API_ADMIN_IS_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_REPORT))
#define TUBA_API_ADMIN_REPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReportClass))

typedef struct _TubaAPIAdminReport TubaAPIAdminReport;
typedef struct _TubaAPIAdminReportClass TubaAPIAdminReportClass;

#define TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING (tuba_api_notification_moderation_warning_get_type ())
#define TUBA_API_NOTIFICATION_MODERATION_WARNING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING, TubaAPINotificationModerationWarning))
#define TUBA_API_NOTIFICATION_MODERATION_WARNING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING, TubaAPINotificationModerationWarningClass))
#define TUBA_API_NOTIFICATION_IS_MODERATION_WARNING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING))
#define TUBA_API_NOTIFICATION_IS_MODERATION_WARNING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING))
#define TUBA_API_NOTIFICATION_MODERATION_WARNING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING, TubaAPINotificationModerationWarningClass))

typedef struct _TubaAPINotificationModerationWarning TubaAPINotificationModerationWarning;
typedef struct _TubaAPINotificationModerationWarningClass TubaAPINotificationModerationWarningClass;

#define TUBA_API_TYPE_COLLECTION (tuba_api_collection_get_type ())
#define TUBA_API_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_COLLECTION, TubaAPICollection))
#define TUBA_API_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_COLLECTION, TubaAPICollectionClass))
#define TUBA_API_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_COLLECTION))
#define TUBA_API_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_COLLECTION))
#define TUBA_API_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_COLLECTION, TubaAPICollectionClass))

typedef struct _TubaAPICollection TubaAPICollection;
typedef struct _TubaAPICollectionClass TubaAPICollectionClass;

#define TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT (tuba_api_notification_relationship_severance_event_get_type ())
#define TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, TubaAPINotificationRelationshipSeveranceEvent))
#define TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, TubaAPINotificationRelationshipSeveranceEventClass))
#define TUBA_API_NOTIFICATION_IS_RELATIONSHIP_SEVERANCE_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT))
#define TUBA_API_NOTIFICATION_IS_RELATIONSHIP_SEVERANCE_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT))
#define TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, TubaAPINotificationRelationshipSeveranceEventClass))

typedef struct _TubaAPINotificationRelationshipSeveranceEvent TubaAPINotificationRelationshipSeveranceEvent;
typedef struct _TubaAPINotificationRelationshipSeveranceEventClass TubaAPINotificationRelationshipSeveranceEventClass;
enum  {
	TUBA_API_NOTIFICATION_0_PROPERTY,
	TUBA_API_NOTIFICATION_ID_PROPERTY,
	TUBA_API_NOTIFICATION_ACCOUNT_PROPERTY,
	TUBA_API_NOTIFICATION_KIND_PROPERTY,
	TUBA_API_NOTIFICATION_CREATED_AT_PROPERTY,
	TUBA_API_NOTIFICATION_STATUS_PROPERTY,
	TUBA_API_NOTIFICATION_EMOJI_PROPERTY,
	TUBA_API_NOTIFICATION_EMOJI_URL_PROPERTY,
	TUBA_API_NOTIFICATION_REPORT_PROPERTY,
	TUBA_API_NOTIFICATION_MODERATION_WARNING_PROPERTY,
	TUBA_API_NOTIFICATION_GROUP_KEY_PROPERTY,
	TUBA_API_NOTIFICATION_COLLECTION_PROPERTY,
	TUBA_API_NOTIFICATION_EVENT_PROPERTY,
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_PROPERTY,
	TUBA_API_NOTIFICATION_NUM_PROPERTIES
};
static GParamSpec* tuba_api_notification_properties[TUBA_API_NOTIFICATION_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())

#define TUBA_TYPE_NETWORK (tuba_network_get_type ())
#define TUBA_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_NETWORK, TubaNetwork))
#define TUBA_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_NETWORK, TubaNetworkClass))
#define TUBA_IS_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_NETWORK))
#define TUBA_IS_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_NETWORK))
#define TUBA_NETWORK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_NETWORK, TubaNetworkClass))

typedef struct _TubaNetwork TubaNetwork;
typedef struct _TubaNetworkClass TubaNetworkClass;

#define TUBA_API_TYPE_ANNUAL_REPORTS (tuba_api_annual_reports_get_type ())
#define TUBA_API_ANNUAL_REPORTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ANNUAL_REPORTS, TubaAPIAnnualReports))
#define TUBA_API_ANNUAL_REPORTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ANNUAL_REPORTS, TubaAPIAnnualReportsClass))
#define TUBA_API_IS_ANNUAL_REPORTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ANNUAL_REPORTS))
#define TUBA_API_IS_ANNUAL_REPORTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ANNUAL_REPORTS))
#define TUBA_API_ANNUAL_REPORTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ANNUAL_REPORTS, TubaAPIAnnualReportsClass))

typedef struct _TubaAPIAnnualReports TubaAPIAnnualReports;
typedef struct _TubaAPIAnnualReportsClass TubaAPIAnnualReportsClass;
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaApiNotificationOpenAnnualReportData TubaApiNotificationOpenAnnualReportData;

#define TUBA_DIALOGS_ADMIN_TYPE_WINDOW (tuba_dialogs_admin_window_get_type ())
#define TUBA_DIALOGS_ADMIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow))
#define TUBA_DIALOGS_ADMIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))

typedef struct _TubaDialogsAdminWindow TubaDialogsAdminWindow;
typedef struct _TubaDialogsAdminWindowClass TubaDialogsAdminWindowClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define TUBA_DIALOGS_TYPE_COLLECTION (tuba_dialogs_collection_get_type ())
#define TUBA_DIALOGS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_COLLECTION, TubaDialogsCollection))
#define TUBA_DIALOGS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_COLLECTION, TubaDialogsCollectionClass))
#define TUBA_DIALOGS_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_COLLECTION))
#define TUBA_DIALOGS_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_COLLECTION))
#define TUBA_DIALOGS_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_COLLECTION, TubaDialogsCollectionClass))

typedef struct _TubaDialogsCollection TubaDialogsCollection;
typedef struct _TubaDialogsCollectionClass TubaDialogsCollectionClass;

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;

#define TUBA_VIEWS_TYPE_TABBED_BASE (tuba_views_tabbed_base_get_type ())
#define TUBA_VIEWS_TABBED_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TABBED_BASE, TubaViewsTabbedBase))
#define TUBA_VIEWS_TABBED_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TABBED_BASE, TubaViewsTabbedBaseClass))
#define TUBA_VIEWS_IS_TABBED_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TABBED_BASE))
#define TUBA_VIEWS_IS_TABBED_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TABBED_BASE))
#define TUBA_VIEWS_TABBED_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TABBED_BASE, TubaViewsTabbedBaseClass))

typedef struct _TubaViewsTabbedBase TubaViewsTabbedBase;
typedef struct _TubaViewsTabbedBaseClass TubaViewsTabbedBaseClass;

#define TUBA_VIEWS_TYPE_COLLECTIONS (tuba_views_collections_get_type ())
#define TUBA_VIEWS_COLLECTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_COLLECTIONS, TubaViewsCollections))
#define TUBA_VIEWS_COLLECTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_COLLECTIONS, TubaViewsCollectionsClass))
#define TUBA_VIEWS_IS_COLLECTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_COLLECTIONS))
#define TUBA_VIEWS_IS_COLLECTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_COLLECTIONS))
#define TUBA_VIEWS_COLLECTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_COLLECTIONS, TubaViewsCollectionsClass))

typedef struct _TubaViewsCollections TubaViewsCollections;
typedef struct _TubaViewsCollectionsClass TubaViewsCollectionsClass;

#define TUBA_API_TYPE_RELATIONSHIP (tuba_api_relationship_get_type ())
#define TUBA_API_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationship))
#define TUBA_API_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))
#define TUBA_API_IS_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_IS_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_RELATIONSHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))

typedef struct _TubaAPIRelationship TubaAPIRelationship;
typedef struct _TubaAPIRelationshipClass TubaAPIRelationshipClass;

#define TUBA_WIDGETS_TYPE_ACCOUNT (tuba_widgets_account_get_type ())
#define TUBA_WIDGETS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount))
#define TUBA_WIDGETS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))
#define TUBA_WIDGETS_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))

typedef struct _TubaWidgetsAccount TubaWidgetsAccount;
typedef struct _TubaWidgetsAccountClass TubaWidgetsAccountClass;

#define TUBA_WIDGETS_TYPE_COLLECTION_ROW (tuba_widgets_collection_row_get_type ())
#define TUBA_WIDGETS_COLLECTION_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_COLLECTION_ROW, TubaWidgetsCollectionRow))
#define TUBA_WIDGETS_COLLECTION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_COLLECTION_ROW, TubaWidgetsCollectionRowClass))
#define TUBA_WIDGETS_IS_COLLECTION_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_COLLECTION_ROW))
#define TUBA_WIDGETS_IS_COLLECTION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_COLLECTION_ROW))
#define TUBA_WIDGETS_COLLECTION_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_COLLECTION_ROW, TubaWidgetsCollectionRowClass))

typedef struct _TubaWidgetsCollectionRow TubaWidgetsCollectionRow;
typedef struct _TubaWidgetsCollectionRowClass TubaWidgetsCollectionRowClass;

#define TUBA_WIDGETS_TYPE_STATUS (tuba_widgets_status_get_type ())
#define TUBA_WIDGETS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatus))
#define TUBA_WIDGETS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))
#define TUBA_WIDGETS_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))

typedef struct _TubaWidgetsStatus TubaWidgetsStatus;
typedef struct _TubaWidgetsStatusClass TubaWidgetsStatusClass;

#define TUBA_WIDGETS_TYPE_NOTIFICATION (tuba_widgets_notification_get_type ())
#define TUBA_WIDGETS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotification))
#define TUBA_WIDGETS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotificationClass))
#define TUBA_WIDGETS_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION))
#define TUBA_WIDGETS_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION))
#define TUBA_WIDGETS_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotificationClass))

typedef struct _TubaWidgetsNotification TubaWidgetsNotification;
typedef struct _TubaWidgetsNotificationClass TubaWidgetsNotificationClass;

#define TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER (tuba_widgets_list_box_row_wrapper_get_type ())
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapper))
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapperClass))
#define TUBA_WIDGETS_IS_LIST_BOX_ROW_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER))
#define TUBA_WIDGETS_IS_LIST_BOX_ROW_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER))
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapperClass))

typedef struct _TubaWidgetsListBoxRowWrapper TubaWidgetsListBoxRowWrapper;
typedef struct _TubaWidgetsListBoxRowWrapperClass TubaWidgetsListBoxRowWrapperClass;

#define TUBA_INSTANCE_ACCOUNT_TYPE_KIND (tuba_instance_account_kind_get_type ())
typedef struct _TubaInstanceAccountKind TubaInstanceAccountKind;

#define TUBA_TYPE_SETTINGS (tuba_settings_get_type ())
#define TUBA_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_SETTINGS, TubaSettings))
#define TUBA_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_SETTINGS, TubaSettingsClass))
#define TUBA_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_SETTINGS))
#define TUBA_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_SETTINGS))
#define TUBA_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_SETTINGS, TubaSettingsClass))

typedef struct _TubaSettings TubaSettings;
typedef struct _TubaSettingsClass TubaSettingsClass;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
#define _g_bytes_unref0(var) ((var == NULL) ? NULL : (var = (g_bytes_unref (var), NULL)))
typedef struct _TubaApiNotificationToToastData TubaApiNotificationToToastData;
typedef struct _TubaAPINotificationRelationshipSeveranceEventPrivate TubaAPINotificationRelationshipSeveranceEventPrivate;
enum  {
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_0_PROPERTY,
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_KIND_PROPERTY,
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_TARGET_NAME_PROPERTY,
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_RELATIONSHIPS_COUNT_PROPERTY,
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWERS_COUNT_PROPERTY,
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWING_COUNT_PROPERTY,
	TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_NUM_PROPERTIES
};
static GParamSpec* tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_NUM_PROPERTIES];
typedef struct _TubaAPINotificationModerationWarningPrivate TubaAPINotificationModerationWarningPrivate;
enum  {
	TUBA_API_NOTIFICATION_MODERATION_WARNING_0_PROPERTY,
	TUBA_API_NOTIFICATION_MODERATION_WARNING_ID_PROPERTY,
	TUBA_API_NOTIFICATION_MODERATION_WARNING_NUM_PROPERTIES
};
static GParamSpec* tuba_api_notification_moderation_warning_properties[TUBA_API_NOTIFICATION_MODERATION_WARNING_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPINotification {
	TubaEntity parent_instance;
	TubaAPINotificationPrivate * priv;
};

struct _TubaAPINotificationClass {
	TubaEntityClass parent_class;
	void (*to_toast) (TubaAPINotification* self, TubaInstanceAccount* issuer, gint others, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GNotification* (*to_toast_finish) (TubaAPINotification* self, GAsyncResult* _res_);
};

struct _TubaAPINotificationPrivate {
	gchar* _id;
	TubaAPIAccount* _account;
	gchar* _kind;
	gchar* _created_at;
	TubaAPIStatus* _status;
	gchar* _emoji;
	gchar* _emoji_url;
	TubaAPIAdminReport* _report;
	TubaAPINotificationModerationWarning* _moderation_warning;
	gchar* _group_key;
	TubaAPICollection* _collection;
	TubaAPINotificationRelationshipSeveranceEvent* _event;
	TubaAPINotificationRelationshipSeveranceEvent* _relationship_severance_event;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaApiNotificationOpenAnnualReportData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaAPINotification* self;
	gint year;
	TubaRequestV2* req;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	TubaAccountStore* _tmp4_;
	TubaInstanceAccount* _tmp5_;
	TubaInstanceAccount* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaRequestV2* _tmp8_;
	TubaRequestV2* _tmp9_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp10_;
	GInputStream* _tmp11_;
	JsonParser* parser;
	GInputStream* _tmp12_;
	JsonParser* _tmp13_;
	JsonNode* node;
	TubaNetwork* _tmp14_;
	JsonParser* _tmp15_;
	JsonNode* _tmp16_;
	TubaAPIAnnualReports* _tmp17_;
	JsonNode* _tmp18_;
	TubaAPIAnnualReports* _tmp19_;
	GError* e;
	GError* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GError* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	AdwAlertDialog* dlg;
	TubaApplication* _tmp28_;
	GError* _tmp29_;
	const gchar* _tmp30_;
	AdwAlertDialog* _tmp31_;
	AdwAlertDialog* _tmp32_;
	TubaApplication* _tmp33_;
	TubaDialogsMainWindow* _tmp34_;
	TubaDialogsMainWindow* _tmp35_;
	GError* _inner_error0_;
};

struct _TubaInstanceAccountKind {
	gchar* icon;
	gchar* description;
	gchar* url;
};

struct _TubaApiNotificationToToastData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaAPINotification* self;
	TubaInstanceAccount* issuer;
	gint others;
	GNotification* result;
	TubaInstanceAccountKind res_kind;
	gboolean should_show_buttons;
	TubaAccountStore* _tmp0_;
	TubaInstanceAccount* _tmp1_;
	TubaInstanceAccount* _tmp2_;
	gchar* kind_actor_name;
	TubaAPIAccount* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gint _tmp19_;
	gint _tmp20_;
	gboolean _tmp21_;
	TubaAPIAccount* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	TubaAPIAccount* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* other_data;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	const gchar* _tmp31_;
	gint _tmp32_;
	const gchar* _tmp33_;
	GDateTime* _tmp34_;
	GDateTime* _tmp35_;
	const gchar* _tmp36_;
	GDateTime* _tmp37_;
	GDateTime* _tmp38_;
	gint year;
	gchar* _tmp39_;
	const gchar* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	TubaInstanceAccountKind _tmp43_;
	GNotification* toast;
	TubaInstanceAccountKind _tmp44_;
	const gchar* _tmp45_;
	GNotification* _tmp46_;
	TubaAPIStatus* _tmp47_;
	gboolean _tmp48_;
	gboolean _tmp49_;
	TubaAPIStatus* _tmp50_;
	const gchar* _tmp51_;
	const gchar* _tmp52_;
	TubaAPIStatus* _tmp53_;
	const gchar* _tmp54_;
	const gchar* _tmp55_;
	TubaSettings* _tmp56_;
	gboolean _tmp57_;
	gboolean _tmp58_;
	GNotification* _tmp59_;
	TubaAPIStatus* _tmp60_;
	const gchar* _tmp61_;
	const gchar* _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
	GNotification* _tmp65_;
	TubaAPIStatus* _tmp66_;
	const gchar* _tmp67_;
	const gchar* _tmp68_;
	gchar* _tmp69_;
	gchar* _tmp70_;
	const gchar* _tmp71_;
	const gchar* _tmp72_;
	GQuark _tmp74_;
	GNotification* _tmp75_;
	GNotification* _tmp76_;
	GNotification* _tmp77_;
	gchar* var_string;
	TubaAPIAccount* _tmp78_;
	const gchar* _tmp79_;
	const gchar* _tmp80_;
	gchar* _tmp81_;
	gboolean _tmp82_;
	TubaAPIStatus* _tmp83_;
	TubaAPIStatus* _tmp84_;
	gchar* _tmp85_;
	gchar* _tmp86_;
	gchar* _tmp87_;
	TubaAPIStatus* _tmp88_;
	gchar* _tmp89_;
	gchar* _tmp90_;
	GNotification* _tmp91_;
	const gchar* _tmp92_;
	GVariant* _tmp93_;
	GVariant* _tmp94_;
	const gchar* _tmp95_;
	const gchar* _tmp96_;
	GQuark _tmp98_;
	TubaAPIStatus* _tmp99_;
	GNotification* _tmp100_;
	TubaAccountStore* _tmp101_;
	TubaInstanceAccount* _tmp102_;
	TubaInstanceAccount* _tmp103_;
	const gchar* _tmp104_;
	const gchar* _tmp105_;
	GVariant* _tmp106_;
	TubaAPIStatus* _tmp107_;
	const gchar* _tmp108_;
	const gchar* _tmp109_;
	GVariant* _tmp110_;
	GVariant** _tmp111_;
	GVariant** _tmp112_;
	gint _tmp112__length1;
	GVariant* _tmp113_;
	GVariant* _tmp114_;
	GNotification* _tmp115_;
	TubaAccountStore* _tmp116_;
	TubaInstanceAccount* _tmp117_;
	TubaInstanceAccount* _tmp118_;
	const gchar* _tmp119_;
	const gchar* _tmp120_;
	GVariant* _tmp121_;
	TubaAPIAccount* _tmp122_;
	const gchar* _tmp123_;
	const gchar* _tmp124_;
	GVariant* _tmp125_;
	GVariant** _tmp126_;
	GVariant** _tmp127_;
	gint _tmp127__length1;
	GVariant* _tmp128_;
	GVariant* _tmp129_;
	GNotification* _tmp130_;
	TubaAccountStore* _tmp131_;
	TubaInstanceAccount* _tmp132_;
	TubaInstanceAccount* _tmp133_;
	const gchar* _tmp134_;
	const gchar* _tmp135_;
	GVariant* _tmp136_;
	TubaAPIAccount* _tmp137_;
	const gchar* _tmp138_;
	const gchar* _tmp139_;
	GVariant* _tmp140_;
	GVariant** _tmp141_;
	GVariant** _tmp142_;
	gint _tmp142__length1;
	GVariant* _tmp143_;
	GVariant* _tmp144_;
	GNotification* _tmp145_;
	TubaAccountStore* _tmp146_;
	TubaInstanceAccount* _tmp147_;
	TubaInstanceAccount* _tmp148_;
	const gchar* _tmp149_;
	const gchar* _tmp150_;
	GVariant* _tmp151_;
	TubaAPIAccount* _tmp152_;
	const gchar* _tmp153_;
	const gchar* _tmp154_;
	GVariant* _tmp155_;
	GVariant* _tmp156_;
	GVariant** _tmp157_;
	GVariant** _tmp158_;
	gint _tmp158__length1;
	GVariant* _tmp159_;
	GVariant* _tmp160_;
	GNotification* _tmp161_;
	TubaAccountStore* _tmp162_;
	TubaInstanceAccount* _tmp163_;
	TubaInstanceAccount* _tmp164_;
	const gchar* _tmp165_;
	const gchar* _tmp166_;
	GVariant* _tmp167_;
	TubaAPIAccount* _tmp168_;
	const gchar* _tmp169_;
	const gchar* _tmp170_;
	GVariant* _tmp171_;
	GVariant* _tmp172_;
	GVariant** _tmp173_;
	GVariant** _tmp174_;
	gint _tmp174__length1;
	GVariant* _tmp175_;
	GVariant* _tmp176_;
	GIcon* icon;
	GBytes* avatar_bytes;
	TubaAPIAccount* _tmp177_;
	const gchar* _tmp178_;
	const gchar* _tmp179_;
	GBytes* _tmp180_;
	GBytes* _tmp181_;
	GBytes* _tmp182_;
	GBytesIcon* _tmp183_;
	GFile* icon_file;
	TubaAPIAccount* _tmp184_;
	const gchar* _tmp185_;
	const gchar* _tmp186_;
	GFile* _tmp187_;
	GFile* _tmp188_;
	GFileIcon* _tmp189_;
	GIcon* _tmp190_;
	GNotification* _tmp191_;
	GIcon* _tmp192_;
};

struct _TubaAPINotificationRelationshipSeveranceEvent {
	TubaEntity parent_instance;
	TubaAPINotificationRelationshipSeveranceEventPrivate * priv;
};

struct _TubaAPINotificationRelationshipSeveranceEventClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINotificationRelationshipSeveranceEventPrivate {
	gchar* _kind;
	gchar* _target_name;
	gint64 _relationships_count;
	gint64 _followers_count;
	gint64 _following_count;
};

struct _TubaAPINotificationModerationWarning {
	TubaEntity parent_instance;
	TubaAPINotificationModerationWarningPrivate * priv;
};

struct _TubaAPINotificationModerationWarningClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINotificationModerationWarningPrivate {
	gchar* _id;
};

static gint TubaAPINotification_private_offset;
static gpointer tuba_api_notification_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
VALA_EXTERN TubaNetwork* tuba_network;
VALA_EXTERN TubaApplication* tuba_app;
VALA_EXTERN TubaSettings* tuba_settings;
VALA_EXTERN gboolean tuba_is_flatpak;
static gint TubaAPINotificationRelationshipSeveranceEvent_private_offset;
static gpointer tuba_api_notification_relationship_severance_event_parent_class = NULL;
static gint TubaAPINotificationModerationWarning_private_offset;
static gpointer tuba_api_notification_moderation_warning_parent_class = NULL;
static TubaWidgetizableIface * tuba_api_notification_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotification, g_object_unref)
VALA_EXTERN GType tuba_api_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIStatus, g_object_unref)
VALA_EXTERN GType tuba_api_admin_report_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminReport, g_object_unref)
VALA_EXTERN GType tuba_api_notification_moderation_warning_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotificationModerationWarning, g_object_unref)
VALA_EXTERN GType tuba_api_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPICollection, g_object_unref)
VALA_EXTERN GType tuba_api_notification_relationship_severance_event_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotificationRelationshipSeveranceEvent, g_object_unref)
VALA_EXTERN void tuba_api_notification_to_toast (TubaAPINotification* self,
                                     TubaInstanceAccount* issuer,
                                     gint others,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN GNotification* tuba_api_notification_to_toast_finish (TubaAPINotification* self,
                                                      GAsyncResult* _res_);
static void tuba_api_notification_open_annual_report_data_free (gpointer _data);
static void tuba_api_notification_open_annual_report (TubaAPINotification* self,
                                               gint year,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
static void tuba_api_notification_open_annual_report_finish (TubaAPINotification* self,
                                                      GAsyncResult* _res_);
static gboolean tuba_api_notification_open_annual_report_co (TubaApiNotificationOpenAnnualReportData* _data_);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_api_notification_open_annual_report_ready (GObject* source_object,
                                                     GAsyncResult* _res_,
                                                     gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN GType tuba_network_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaNetwork, g_object_unref)
VALA_EXTERN JsonNode* tuba_network_parse_node (TubaNetwork* self,
                                   JsonParser* parser);
VALA_EXTERN GType tuba_api_annual_reports_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAnnualReports, g_object_unref)
VALA_EXTERN TubaAPIAnnualReports* tuba_api_annual_reports_from (JsonNode* node,
                                                    GError** error);
static void _vala_JsonNode_free (JsonNode* self);
VALA_EXTERN void tuba_api_annual_reports_open (TubaAPIAnnualReports* self,
                                   gint year);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN AdwAlertDialog* tuba_application_inform (TubaApplication* self,
                                         const gchar* text,
                                         const gchar* msg);
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
static void tuba_api_notification_real_open (TubaWidgetizable* base);
VALA_EXTERN const gchar* tuba_api_notification_get_kind (TubaAPINotification* self);
VALA_EXTERN void tuba_utils_host_open_url (const gchar* _uri,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN gboolean tuba_utils_host_open_url_finish (GAsyncResult* _res_);
VALA_EXTERN const gchar* tuba_instance_account_get_instance (TubaInstanceAccount* self);
VALA_EXTERN TubaAPINotificationModerationWarning* tuba_api_notification_get_moderation_warning (TubaAPINotification* self);
VALA_EXTERN const gchar* tuba_api_notification_moderation_warning_get_id (TubaAPINotificationModerationWarning* self);
VALA_EXTERN TubaAPIAdminReport* tuba_api_notification_get_report (TubaAPINotification* self);
VALA_EXTERN gboolean tuba_instance_account_get_admin_mode (TubaInstanceAccount* self);
VALA_EXTERN GType tuba_dialogs_admin_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsAdminWindow, g_object_unref)
VALA_EXTERN TubaDialogsAdminWindow* tuba_dialogs_admin_window_new (void);
VALA_EXTERN TubaDialogsAdminWindow* tuba_dialogs_admin_window_construct (GType object_type);
VALA_EXTERN void tuba_dialogs_admin_window_open_reports (TubaDialogsAdminWindow* self);
VALA_EXTERN const gchar* tuba_api_admin_report_get_id (TubaAPIAdminReport* self);
VALA_EXTERN const gchar* tuba_api_notification_get_created_at (TubaAPINotification* self);
VALA_EXTERN TubaAPICollection* tuba_api_notification_get_collection (TubaAPINotification* self);
VALA_EXTERN TubaDialogsCollection* tuba_dialogs_collection_new (TubaAPICollection* collection);
VALA_EXTERN TubaDialogsCollection* tuba_dialogs_collection_construct (GType object_type,
                                                          TubaAPICollection* collection);
VALA_EXTERN GType tuba_dialogs_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsCollection, g_object_unref)
VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN TubaViewsBase* tuba_dialogs_main_window_open_view (TubaDialogsMainWindow* self,
                                                   TubaViewsBase* view);
VALA_EXTERN TubaViewsCollections* tuba_views_collections_new (void);
VALA_EXTERN TubaViewsCollections* tuba_views_collections_construct (GType object_type);
VALA_EXTERN GType tuba_views_tabbed_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTabbedBase, g_object_unref)
VALA_EXTERN GType tuba_views_collections_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsCollections, g_object_unref)
static gboolean _vala_string_array_contains (const gchar* * stack,
                                      gssize stack_length,
                                      const const gchar* needle);
VALA_EXTERN TubaAPIStatus* tuba_api_notification_get_status (TubaAPINotification* self);
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
VALA_EXTERN TubaAPIAccount* tuba_api_notification_get_account (TubaAPINotification* self);
static GtkWidget* tuba_api_notification_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN TubaAPIRelationship* tuba_api_relationship_new_for_account (TubaAPIAccount* acc);
VALA_EXTERN TubaAPIRelationship* tuba_api_relationship_construct_for_account (GType object_type,
                                                                  TubaAPIAccount* acc);
VALA_EXTERN GType tuba_api_relationship_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIRelationship, g_object_unref)
VALA_EXTERN void tuba_api_account_set_tuba_rs (TubaAPIAccount* self,
                                   TubaAPIRelationship* value);
VALA_EXTERN TubaWidgetsAccount* tuba_widgets_account_new (TubaAPIAccount* account);
VALA_EXTERN TubaWidgetsAccount* tuba_widgets_account_construct (GType object_type,
                                                    TubaAPIAccount* account);
VALA_EXTERN GType tuba_widgets_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccount, g_object_unref)
VALA_EXTERN void tuba_widgets_account_set_additional_label (TubaWidgetsAccount* self,
                                                const gchar* value);
VALA_EXTERN TubaAPINotificationRelationshipSeveranceEvent* tuba_api_notification_get_event (TubaAPINotification* self);
VALA_EXTERN TubaAPINotificationRelationshipSeveranceEvent* tuba_api_notification_get_relationship_severance_event (TubaAPINotification* self);
static GtkWidget* tuba_api_notification_create_basic_card (TubaAPINotification* self,
                                                    const gchar* icon_name,
                                                    const gchar* label,
                                                    GtkWidget* extra_widget);
VALA_EXTERN gchar* tuba_api_notification_relationship_severance_event_to_string (TubaAPINotificationRelationshipSeveranceEvent* self);
VALA_EXTERN gchar* tuba_api_admin_report_to_string (TubaAPIAdminReport* self,
                                        const gchar* created_at);
VALA_EXTERN GType tuba_widgets_collection_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsCollectionRow, g_object_unref)
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN TubaWidgetsNotification* tuba_widgets_notification_new (TubaAPINotification* obj,
                                                        gboolean with_kind);
VALA_EXTERN TubaWidgetsNotification* tuba_widgets_notification_construct (GType object_type,
                                                              TubaAPINotification* obj,
                                                              gboolean with_kind);
VALA_EXTERN GType tuba_widgets_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsStatus, g_object_unref)
VALA_EXTERN GType tuba_widgets_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsNotification, g_object_unref)
VALA_EXTERN GType tuba_widgets_list_box_row_wrapper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsListBoxRowWrapper, g_object_unref)
VALA_EXTERN TubaWidgetsListBoxRowWrapper* tuba_widgets_list_box_row_wrapper_new (void);
VALA_EXTERN TubaWidgetsListBoxRowWrapper* tuba_widgets_list_box_row_wrapper_construct (GType object_type);
static void _tuba_widgetizable_open_tuba_widgets_list_box_row_wrapper_open (TubaWidgetsListBoxRowWrapper* _sender,
                                                                     gpointer self);
static void tuba_api_notification_real_to_toast_data_free (gpointer _data);
static void tuba_api_notification_real_to_toast (TubaAPINotification* self,
                                          TubaInstanceAccount* issuer,
                                          gint others,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
static gboolean tuba_api_notification_real_to_toast_co (TubaApiNotificationToToastData* _data_);
VALA_EXTERN GType tuba_instance_account_kind_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaInstanceAccountKind* tuba_instance_account_kind_dup (const TubaInstanceAccountKind* self);
VALA_EXTERN void tuba_instance_account_kind_free (TubaInstanceAccountKind* self);
VALA_EXTERN void tuba_instance_account_kind_copy (const TubaInstanceAccountKind* self,
                                      TubaInstanceAccountKind* dest);
VALA_EXTERN void tuba_instance_account_kind_destroy (TubaInstanceAccountKind* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaInstanceAccountKind, tuba_instance_account_kind_destroy)
VALA_EXTERN const gchar* tuba_api_account_get_display_name (TubaAPIAccount* self);
VALA_EXTERN gchar* tuba_api_account_get_handle (TubaAPIAccount* self);
VALA_EXTERN const gchar* tuba_api_notification_get_emoji (TubaAPINotification* self);
VALA_EXTERN void tuba_instance_account_describe_kind (TubaInstanceAccount* self,
                                          const gchar* kind,
                                          TubaInstanceAccountKind* _result_,
                                          const gchar* actor_name,
                                          const gchar* callback_url,
                                          const gchar* other_data);
VALA_EXTERN const gchar* tuba_api_status_get_spoiler_text (TubaAPIStatus* self);
VALA_EXTERN GType tuba_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettings, g_object_unref)
VALA_EXTERN gboolean tuba_settings_get_show_spoilers (TubaSettings* self);
VALA_EXTERN gchar* tuba_utils_htmlx_remove_tags (const gchar* content);
VALA_EXTERN const gchar* tuba_api_status_get_content (TubaAPIStatus* self);
VALA_EXTERN const gchar* tuba_api_account_get_url (TubaAPIAccount* self);
VALA_EXTERN gchar* tuba_api_status_get_url (TubaAPIStatus* self);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
static GVariant* _variant_new1 (const gchar* value);
VALA_EXTERN const gchar* tuba_api_status_get_uri (TubaAPIStatus* self);
static GVariant* _variant_new2 (const gchar* value);
static GVariant* _variant_new3 (const gchar* value);
static GVariant* _variant_new4 (const gchar* value);
static GVariant* _variant_new5 (const gchar* value);
static GVariant* _variant_new6 (const gchar* value);
static GVariant* _variant_new7 (const gchar* value);
static GVariant* _variant_new8 (const gchar* value);
static GVariant* _variant_new9 (gboolean value);
static GVariant* _variant_new10 (const gchar* value);
static GVariant* _variant_new11 (const gchar* value);
static GVariant* _variant_new12 (gboolean value);
VALA_EXTERN void tuba_helper_image_request_bytes (const gchar* url,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN GBytes* tuba_helper_image_request_bytes_finish (GAsyncResult* _res_);
VALA_EXTERN const gchar* tuba_api_account_get_avatar (TubaAPIAccount* self);
static void tuba_api_notification_to_toast_ready (GObject* source_object,
                                           GAsyncResult* _res_,
                                           gpointer _user_data_);
VALA_EXTERN TubaAPINotification* tuba_api_notification_new (void);
VALA_EXTERN TubaAPINotification* tuba_api_notification_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_notification_get_id (TubaAPINotification* self);
VALA_EXTERN void tuba_api_notification_set_id (TubaAPINotification* self,
                                   const gchar* value);
VALA_EXTERN void tuba_api_notification_set_account (TubaAPINotification* self,
                                        TubaAPIAccount* value);
VALA_EXTERN void tuba_api_notification_set_kind (TubaAPINotification* self,
                                     const gchar* value);
VALA_EXTERN void tuba_api_notification_set_created_at (TubaAPINotification* self,
                                           const gchar* value);
VALA_EXTERN void tuba_api_notification_set_status (TubaAPINotification* self,
                                       TubaAPIStatus* value);
VALA_EXTERN void tuba_api_notification_set_emoji (TubaAPINotification* self,
                                      const gchar* value);
VALA_EXTERN const gchar* tuba_api_notification_get_emoji_url (TubaAPINotification* self);
VALA_EXTERN void tuba_api_notification_set_emoji_url (TubaAPINotification* self,
                                          const gchar* value);
VALA_EXTERN void tuba_api_notification_set_report (TubaAPINotification* self,
                                       TubaAPIAdminReport* value);
VALA_EXTERN void tuba_api_notification_set_moderation_warning (TubaAPINotification* self,
                                                   TubaAPINotificationModerationWarning* value);
VALA_EXTERN const gchar* tuba_api_notification_get_group_key (TubaAPINotification* self);
VALA_EXTERN void tuba_api_notification_set_group_key (TubaAPINotification* self,
                                          const gchar* value);
VALA_EXTERN void tuba_api_notification_set_collection (TubaAPINotification* self,
                                           TubaAPICollection* value);
VALA_EXTERN void tuba_api_notification_set_event (TubaAPINotification* self,
                                      TubaAPINotificationRelationshipSeveranceEvent* value);
VALA_EXTERN void tuba_api_notification_set_relationship_severance_event (TubaAPINotification* self,
                                                             TubaAPINotificationRelationshipSeveranceEvent* value);
VALA_EXTERN const gchar* tuba_api_notification_relationship_severance_event_get_kind (TubaAPINotificationRelationshipSeveranceEvent* self);
VALA_EXTERN gint64 tuba_api_notification_relationship_severance_event_get_following_count (TubaAPINotificationRelationshipSeveranceEvent* self);
VALA_EXTERN const gchar* tuba_api_notification_relationship_severance_event_get_target_name (TubaAPINotificationRelationshipSeveranceEvent* self);
VALA_EXTERN gint64 tuba_api_notification_relationship_severance_event_get_followers_count (TubaAPINotificationRelationshipSeveranceEvent* self);
VALA_EXTERN TubaAPINotificationRelationshipSeveranceEvent* tuba_api_notification_relationship_severance_event_new (void);
VALA_EXTERN TubaAPINotificationRelationshipSeveranceEvent* tuba_api_notification_relationship_severance_event_construct (GType object_type);
VALA_EXTERN void tuba_api_notification_relationship_severance_event_set_kind (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                  const gchar* value);
VALA_EXTERN void tuba_api_notification_relationship_severance_event_set_target_name (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                         const gchar* value);
VALA_EXTERN gint64 tuba_api_notification_relationship_severance_event_get_relationships_count (TubaAPINotificationRelationshipSeveranceEvent* self);
VALA_EXTERN void tuba_api_notification_relationship_severance_event_set_relationships_count (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                                 gint64 value);
VALA_EXTERN void tuba_api_notification_relationship_severance_event_set_followers_count (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                             gint64 value);
VALA_EXTERN void tuba_api_notification_relationship_severance_event_set_following_count (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                             gint64 value);
static void tuba_api_notification_relationship_severance_event_finalize (GObject * obj);
static GType tuba_api_notification_relationship_severance_event_get_type_once (void);
static void _vala_tuba_api_notification_relationship_severance_event_get_property (GObject * object,
                                                                            guint property_id,
                                                                            GValue * value,
                                                                            GParamSpec * pspec);
static void _vala_tuba_api_notification_relationship_severance_event_set_property (GObject * object,
                                                                            guint property_id,
                                                                            const GValue * value,
                                                                            GParamSpec * pspec);
VALA_EXTERN TubaAPINotificationModerationWarning* tuba_api_notification_moderation_warning_new (void);
VALA_EXTERN TubaAPINotificationModerationWarning* tuba_api_notification_moderation_warning_construct (GType object_type);
VALA_EXTERN void tuba_api_notification_moderation_warning_set_id (TubaAPINotificationModerationWarning* self,
                                                      const gchar* value);
static void tuba_api_notification_moderation_warning_finalize (GObject * obj);
static GType tuba_api_notification_moderation_warning_get_type_once (void);
static void _vala_tuba_api_notification_moderation_warning_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_tuba_api_notification_moderation_warning_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
static void tuba_api_notification_finalize (GObject * obj);
static GType tuba_api_notification_get_type_once (void);
static void _vala_tuba_api_notification_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_tuba_api_notification_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

VALA_EXTERN const gchar* TUBA_INSTANCE_ACCOUNT_ALL_HANDLED_NOTIFICATION_TYPES[21];

static inline gpointer
tuba_api_notification_get_instance_private (TubaAPINotification* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINotification_private_offset);
}

static void
tuba_api_notification_open_annual_report_data_free (gpointer _data)
{
	TubaApiNotificationOpenAnnualReportData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaApiNotificationOpenAnnualReportData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_api_notification_open_annual_report (TubaAPINotification* self,
                                          gint year,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_)
{
	TubaApiNotificationOpenAnnualReportData* _data_;
	TubaAPINotification* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaApiNotificationOpenAnnualReportData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_api_notification_open_annual_report_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_data_->year = year;
	tuba_api_notification_open_annual_report_co (_data_);
}

static void
tuba_api_notification_open_annual_report_finish (TubaAPINotification* self,
                                                 GAsyncResult* _res_)
{
	TubaApiNotificationOpenAnnualReportData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_api_notification_open_annual_report_ready (GObject* source_object,
                                                GAsyncResult* _res_,
                                                gpointer _user_data_)
{
	TubaApiNotificationOpenAnnualReportData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_api_notification_open_annual_report_co (_data_);
}

static void
_vala_JsonNode_free (JsonNode* self)
{
	g_boxed_free (json_node_get_type (), self);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gboolean
tuba_api_notification_open_annual_report_co (TubaApiNotificationOpenAnnualReportData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = g_strdup_printf ("%i", _data_->year);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_tmp2_ = g_strconcat ("/api/v1/annual_reports/", _data_->_tmp1_, NULL);
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_tmp4_ = tuba_accounts;
	_data_->_tmp5_ = tuba_account_store_get_active (_data_->_tmp4_);
	_data_->_tmp6_ = _data_->_tmp5_;
	_data_->_tmp7_ = _g_object_ref0 (_data_->_tmp6_);
	_data_->_tmp8_ = NULL;
	_data_->_tmp8_ = tuba_request_v2_new (_data_->_tmp3_, TUBA_REQUEST_V2_METHOD_GET);
	tuba_request_v2_set_account (_data_->_tmp8_, _data_->_tmp7_);
	_g_object_unref0 (_data_->_tmp7_);
	_data_->_tmp9_ = _data_->_tmp8_;
	_g_free0 (_data_->_tmp3_);
	_g_free0 (_data_->_tmp1_);
	_data_->req = _data_->_tmp9_;
	{
		_data_->_tmp10_ = _data_->req;
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->_tmp10_, tuba_api_notification_open_annual_report_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp11_ = tuba_request_v2_exec_finish (_data_->_tmp10_, _data_->_res_, NULL, &_data_->_inner_error0_);
		_data_->in_stream = _data_->_tmp11_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			if (g_error_matches (_data_->_inner_error0_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
				goto __catch0_g_io_error_cancelled;
			}
			goto __catch0_g_error;
		}
		_data_->_tmp12_ = _data_->in_stream;
		_data_->_state_ = 2;
		tuba_network_get_parser_from_inputstream_async (_data_->_tmp12_, NULL, tuba_api_notification_open_annual_report_ready, _data_);
		return FALSE;
		_state_2:
		_data_->_tmp13_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
		_data_->parser = _data_->_tmp13_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->in_stream);
			if (g_error_matches (_data_->_inner_error0_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
				goto __catch0_g_io_error_cancelled;
			}
			goto __catch0_g_error;
		}
		_data_->_tmp14_ = tuba_network;
		_data_->_tmp15_ = _data_->parser;
		_data_->_tmp16_ = tuba_network_parse_node (_data_->_tmp14_, _data_->_tmp15_);
		_data_->node = _data_->_tmp16_;
		_data_->_tmp18_ = _data_->node;
		_data_->_tmp19_ = tuba_api_annual_reports_from (_data_->_tmp18_, &_data_->_inner_error0_);
		_data_->_tmp17_ = _data_->_tmp19_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			__vala_JsonNode_free0 (_data_->node);
			_g_object_unref0 (_data_->parser);
			_g_object_unref0 (_data_->in_stream);
			if (g_error_matches (_data_->_inner_error0_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
				goto __catch0_g_io_error_cancelled;
			}
			goto __catch0_g_error;
		}
		tuba_api_annual_reports_open (_data_->_tmp17_, _data_->year);
		_g_object_unref0 (_data_->_tmp17_);
		__vala_JsonNode_free0 (_data_->node);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
	}
	goto __finally0;
	__catch0_g_io_error_cancelled:
	{
		g_clear_error (&_data_->_inner_error0_);
		g_debug ("Notification.vala:77: Message is cancelled.");
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp20_ = _data_->e;
		_data_->_tmp21_ = g_strdup_printf ("%i", _data_->_tmp20_->code);
		_data_->_tmp22_ = _data_->_tmp21_;
		_data_->_tmp23_ = _data_->e;
		_data_->_tmp24_ = _data_->_tmp23_->message;
		_data_->_tmp25_ = string_to_string (_data_->_tmp24_);
		_data_->_tmp26_ = g_strconcat ("Error while opening annual report: ", _data_->_tmp22_, " ", _data_->_tmp25_, NULL);
		_data_->_tmp27_ = _data_->_tmp26_;
		g_warning ("Notification.vala:79: %s", _data_->_tmp27_);
		_g_free0 (_data_->_tmp27_);
		_g_free0 (_data_->_tmp22_);
		_data_->_tmp28_ = tuba_app;
		_data_->_tmp29_ = _data_->e;
		_data_->_tmp30_ = _data_->_tmp29_->message;
		_data_->_tmp31_ = tuba_application_inform (_data_->_tmp28_, _ ("Error"), _data_->_tmp30_);
		_data_->dlg = _data_->_tmp31_;
		_data_->_tmp32_ = _data_->dlg;
		_data_->_tmp33_ = tuba_app;
		_data_->_tmp34_ = tuba_application_get_main_window (_data_->_tmp33_);
		_data_->_tmp35_ = _data_->_tmp34_;
		adw_dialog_present ((AdwDialog*) _data_->_tmp32_, (GtkWidget*) _data_->_tmp35_);
		_g_object_unref0 (_data_->dlg);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->req);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->req);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static gboolean
_vala_string_array_contains (const gchar* * stack,
                             gssize stack_length,
                             const const gchar* needle)
{
	gssize i;
	for (i = 0; i < stack_length; i++) {
		if (g_strcmp0 (stack[i], needle) == 0) {
			return TRUE;
		}
	}
	return FALSE;
}

static void
tuba_api_notification_real_open (TubaWidgetizable* base)
{
	TubaAPINotification * self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
	static GQuark _tmp2_label0 = 0;
	static GQuark _tmp2_label1 = 0;
	static GQuark _tmp2_label2 = 0;
	static GQuark _tmp2_label3 = 0;
	static GQuark _tmp2_label4 = 0;
	static GQuark _tmp2_label5 = 0;
	self = (TubaAPINotification*) base;
	_tmp0_ = self->priv->_kind;
	_tmp1_ = _tmp0_;
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_SEVERED_RELATIONSHIPS)))) {
		switch (0) {
			default:
			{
				TubaAccountStore* _tmp4_;
				TubaInstanceAccount* _tmp5_;
				TubaInstanceAccount* _tmp6_;
				const gchar* _tmp7_;
				const gchar* _tmp8_;
				const gchar* _tmp9_;
				gchar* _tmp10_;
				gchar* _tmp11_;
				_tmp4_ = tuba_accounts;
				_tmp5_ = tuba_account_store_get_active (_tmp4_);
				_tmp6_ = _tmp5_;
				_tmp7_ = tuba_instance_account_get_instance (_tmp6_);
				_tmp8_ = _tmp7_;
				_tmp9_ = string_to_string (_tmp8_);
				_tmp10_ = g_strconcat (_tmp9_, "/severed_relationships", NULL);
				_tmp11_ = _tmp10_;
				tuba_utils_host_open_url (_tmp11_, NULL, NULL);
				_g_free0 (_tmp11_);
				break;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_MODERATION_WARNING)))) {
		switch (0) {
			default:
			{
				const gchar* _tmp12_ = NULL;
				TubaAPINotificationModerationWarning* _tmp13_;
				gchar* dispute_id = NULL;
				gchar* _tmp17_;
				TubaAccountStore* _tmp18_;
				TubaInstanceAccount* _tmp19_;
				TubaInstanceAccount* _tmp20_;
				const gchar* _tmp21_;
				const gchar* _tmp22_;
				const gchar* _tmp23_;
				const gchar* _tmp24_;
				const gchar* _tmp25_;
				gchar* _tmp26_;
				gchar* _tmp27_;
				_tmp13_ = self->priv->_moderation_warning;
				if (_tmp13_ == NULL) {
					_tmp12_ = "";
				} else {
					TubaAPINotificationModerationWarning* _tmp14_;
					const gchar* _tmp15_;
					const gchar* _tmp16_;
					_tmp14_ = self->priv->_moderation_warning;
					_tmp15_ = tuba_api_notification_moderation_warning_get_id (_tmp14_);
					_tmp16_ = _tmp15_;
					_tmp12_ = _tmp16_;
				}
				_tmp17_ = g_strdup (_tmp12_);
				dispute_id = _tmp17_;
				_tmp18_ = tuba_accounts;
				_tmp19_ = tuba_account_store_get_active (_tmp18_);
				_tmp20_ = _tmp19_;
				_tmp21_ = tuba_instance_account_get_instance (_tmp20_);
				_tmp22_ = _tmp21_;
				_tmp23_ = string_to_string (_tmp22_);
				_tmp24_ = dispute_id;
				_tmp25_ = string_to_string (_tmp24_);
				_tmp26_ = g_strconcat (_tmp23_, "/disputes/strikes/", _tmp25_, NULL);
				_tmp27_ = _tmp26_;
				tuba_utils_host_open_url (_tmp27_, NULL, NULL);
				_g_free0 (_tmp27_);
				_g_free0 (dispute_id);
				break;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_REPORT)))) {
		switch (0) {
			default:
			{
				TubaAPIAdminReport* _tmp28_;
				_tmp28_ = self->priv->_report;
				if (_tmp28_ != NULL) {
					TubaAccountStore* _tmp29_;
					TubaInstanceAccount* _tmp30_;
					TubaInstanceAccount* _tmp31_;
					gboolean _tmp32_;
					gboolean _tmp33_;
					_tmp29_ = tuba_accounts;
					_tmp30_ = tuba_account_store_get_active (_tmp29_);
					_tmp31_ = _tmp30_;
					_tmp32_ = tuba_instance_account_get_admin_mode (_tmp31_);
					_tmp33_ = _tmp32_;
					if (_tmp33_) {
						TubaDialogsAdminWindow* admin_window = NULL;
						TubaDialogsAdminWindow* _tmp34_;
						TubaDialogsAdminWindow* _tmp35_;
						TubaDialogsAdminWindow* _tmp36_;
						_tmp34_ = tuba_dialogs_admin_window_new ();
						g_object_ref_sink (_tmp34_);
						admin_window = _tmp34_;
						_tmp35_ = admin_window;
						gtk_window_present ((GtkWindow*) _tmp35_);
						_tmp36_ = admin_window;
						tuba_dialogs_admin_window_open_reports (_tmp36_);
						_g_object_unref0 (admin_window);
					} else {
						TubaAccountStore* _tmp37_;
						TubaInstanceAccount* _tmp38_;
						TubaInstanceAccount* _tmp39_;
						const gchar* _tmp40_;
						const gchar* _tmp41_;
						const gchar* _tmp42_;
						TubaAPIAdminReport* _tmp43_;
						const gchar* _tmp44_;
						const gchar* _tmp45_;
						const gchar* _tmp46_;
						gchar* _tmp47_;
						gchar* _tmp48_;
						_tmp37_ = tuba_accounts;
						_tmp38_ = tuba_account_store_get_active (_tmp37_);
						_tmp39_ = _tmp38_;
						_tmp40_ = tuba_instance_account_get_instance (_tmp39_);
						_tmp41_ = _tmp40_;
						_tmp42_ = string_to_string (_tmp41_);
						_tmp43_ = self->priv->_report;
						_tmp44_ = tuba_api_admin_report_get_id (_tmp43_);
						_tmp45_ = _tmp44_;
						_tmp46_ = string_to_string (_tmp45_);
						_tmp47_ = g_strconcat (_tmp42_, "/admin/reports/", _tmp46_, NULL);
						_tmp48_ = _tmp47_;
						tuba_utils_host_open_url (_tmp48_, NULL, NULL);
						_g_free0 (_tmp48_);
					}
				}
				break;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ANNUAL_REPORT)))) {
		switch (0) {
			default:
			{
				gint year = 0;
				const gchar* _tmp49_;
				_tmp49_ = self->priv->_created_at;
				if (_tmp49_ == NULL) {
					GDateTime* now = NULL;
					GDateTime* _tmp50_;
					gint _tmp51_ = 0;
					GDateTime* _tmp52_;
					_tmp50_ = g_date_time_new_now_local ();
					now = _tmp50_;
					_tmp52_ = now;
					if (g_date_time_get_month (_tmp52_) >= 11) {
						GDateTime* _tmp53_;
						_tmp53_ = now;
						_tmp51_ = g_date_time_get_year (_tmp53_);
					} else {
						GDateTime* _tmp54_;
						_tmp54_ = now;
						_tmp51_ = g_date_time_get_year (_tmp54_) - 1;
					}
					year = _tmp51_;
					_g_date_time_unref0 (now);
				} else {
					const gchar* _tmp55_;
					GDateTime* _tmp56_;
					GDateTime* _tmp57_;
					_tmp55_ = self->priv->_created_at;
					_tmp56_ = g_date_time_new_from_iso8601 (_tmp55_, NULL);
					_tmp57_ = _tmp56_;
					year = g_date_time_get_year (_tmp57_);
					_g_date_time_unref0 (_tmp57_);
				}
				tuba_api_notification_open_annual_report (self, year, NULL, NULL);
				break;
			}
		}
	} else if ((_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_ADDED)))) || (_tmp3_ == ((0 != _tmp2_label5) ? _tmp2_label5 : (_tmp2_label5 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_EDITED))))) {
		switch (0) {
			default:
			{
				TubaAPICollection* _tmp58_;
				_tmp58_ = self->priv->_collection;
				if (_tmp58_ != NULL) {
					TubaAPICollection* _tmp59_;
					TubaDialogsCollection* _tmp60_;
					TubaDialogsCollection* _tmp61_;
					TubaApplication* _tmp62_;
					TubaDialogsMainWindow* _tmp63_;
					TubaDialogsMainWindow* _tmp64_;
					_tmp59_ = self->priv->_collection;
					_tmp60_ = tuba_dialogs_collection_new (_tmp59_);
					g_object_ref_sink (_tmp60_);
					_tmp61_ = _tmp60_;
					_tmp62_ = tuba_app;
					_tmp63_ = tuba_application_get_main_window (_tmp62_);
					_tmp64_ = _tmp63_;
					adw_dialog_present ((AdwDialog*) _tmp61_, (GtkWidget*) _tmp64_);
					_g_object_unref0 (_tmp61_);
				} else {
					TubaApplication* _tmp65_;
					TubaDialogsMainWindow* _tmp66_;
					TubaDialogsMainWindow* _tmp67_;
					TubaViewsCollections* _tmp68_;
					TubaViewsCollections* _tmp69_;
					TubaViewsBase* _tmp70_;
					TubaViewsBase* _tmp71_;
					_tmp65_ = tuba_app;
					_tmp66_ = tuba_application_get_main_window (_tmp65_);
					_tmp67_ = _tmp66_;
					_tmp68_ = tuba_views_collections_new ();
					g_object_ref_sink (_tmp68_);
					_tmp69_ = _tmp68_;
					_tmp70_ = tuba_dialogs_main_window_open_view (_tmp67_, (TubaViewsBase*) _tmp69_);
					_tmp71_ = _tmp70_;
					_g_object_unref0 (_tmp71_);
					_g_object_unref0 (_tmp69_);
				}
				break;
			}
		}
	} else {
		switch (0) {
			default:
			{
				const gchar* _tmp72_;
				_tmp72_ = self->priv->_kind;
				if (_vala_string_array_contains (TUBA_INSTANCE_ACCOUNT_ALL_HANDLED_NOTIFICATION_TYPES, G_N_ELEMENTS (TUBA_INSTANCE_ACCOUNT_ALL_HANDLED_NOTIFICATION_TYPES), _tmp72_)) {
					TubaAPIStatus* _tmp73_;
					_tmp73_ = self->priv->_status;
					if (_tmp73_ != NULL) {
						TubaAPIStatus* _tmp74_;
						_tmp74_ = self->priv->_status;
						tuba_widgetizable_open ((TubaWidgetizable*) _tmp74_);
					} else {
						TubaAPIAccount* _tmp75_;
						_tmp75_ = self->priv->_account;
						tuba_widgetizable_open ((TubaWidgetizable*) _tmp75_);
					}
				}
				break;
			}
		}
	}
}

static GtkWidget*
tuba_api_notification_real_to_widget (TubaWidgetizable* base)
{
	TubaAPINotification * self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
	static GQuark _tmp2_label0 = 0;
	static GQuark _tmp2_label1 = 0;
	static GQuark _tmp2_label2 = 0;
	static GQuark _tmp2_label3 = 0;
	static GQuark _tmp2_label4 = 0;
	static GQuark _tmp2_label5 = 0;
	static GQuark _tmp2_label6 = 0;
	static GQuark _tmp2_label7 = 0;
	static GQuark _tmp2_label8 = 0;
	GtkWidget* result;
	self = (TubaAPINotification*) base;
	_tmp0_ = self->priv->_kind;
	_tmp1_ = _tmp0_;
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
	if ((_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW)))) || (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST))))) {
		switch (0) {
			default:
			{
				TubaAPIAccount* _tmp4_;
				TubaAPIAccount* _tmp5_;
				TubaAPIRelationship* _tmp6_;
				TubaAPIRelationship* _tmp7_;
				TubaAPIAccount* _tmp8_;
				TubaWidgetsAccount* _tmp9_;
				_tmp4_ = self->priv->_account;
				_tmp5_ = self->priv->_account;
				_tmp6_ = tuba_api_relationship_new_for_account (_tmp5_);
				_tmp7_ = _tmp6_;
				tuba_api_account_set_tuba_rs (_tmp4_, _tmp7_);
				_g_object_unref0 (_tmp7_);
				_tmp8_ = self->priv->_account;
				_tmp9_ = tuba_widgets_account_new (_tmp8_);
				g_object_ref_sink (_tmp9_);
				result = (GtkWidget*) _tmp9_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP)))) {
		switch (0) {
			default:
			{
				TubaAPIAccount* _tmp10_;
				TubaAPIAccount* _tmp11_;
				TubaAPIRelationship* _tmp12_;
				TubaAPIRelationship* _tmp13_;
				TubaAPIAccount* _tmp14_;
				gchar* _tmp15_;
				TubaWidgetsAccount* _tmp16_ = NULL;
				_tmp10_ = self->priv->_account;
				_tmp11_ = self->priv->_account;
				_tmp12_ = tuba_api_relationship_new_for_account (_tmp11_);
				_tmp13_ = _tmp12_;
				tuba_api_account_set_tuba_rs (_tmp10_, _tmp13_);
				_g_object_unref0 (_tmp13_);
				_tmp14_ = self->priv->_account;
				_tmp15_ = g_strdup (_ ("Signed Up"));
				_tmp16_ = tuba_widgets_account_new (_tmp14_);
				tuba_widgets_account_set_additional_label (_tmp16_, _tmp15_);
				_g_free0 (_tmp15_);
				g_object_ref_sink (_tmp16_);
				result = (GtkWidget*) _tmp16_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_SEVERED_RELATIONSHIPS)))) {
		switch (0) {
			default:
			{
				TubaAPINotificationRelationshipSeveranceEvent* _tmp17_ = NULL;
				TubaAPINotificationRelationshipSeveranceEvent* _tmp18_;
				TubaAPINotificationRelationshipSeveranceEvent* t_event = NULL;
				TubaAPINotificationRelationshipSeveranceEvent* _tmp21_;
				TubaAPINotificationRelationshipSeveranceEvent* _tmp22_;
				gchar* _tmp23_;
				gchar* _tmp24_;
				GtkWidget* _tmp25_;
				GtkWidget* _tmp26_;
				_tmp18_ = self->priv->_event;
				if (_tmp18_ == NULL) {
					TubaAPINotificationRelationshipSeveranceEvent* _tmp19_;
					_tmp19_ = self->priv->_relationship_severance_event;
					_tmp17_ = _tmp19_;
				} else {
					TubaAPINotificationRelationshipSeveranceEvent* _tmp20_;
					_tmp20_ = self->priv->_event;
					_tmp17_ = _tmp20_;
				}
				_tmp21_ = _g_object_ref0 (_tmp17_);
				t_event = _tmp21_;
				_tmp22_ = t_event;
				_tmp23_ = tuba_api_notification_relationship_severance_event_to_string (_tmp22_);
				_tmp24_ = _tmp23_;
				_tmp25_ = tuba_api_notification_create_basic_card (self, "tuba-heart-broken-symbolic", _tmp24_, NULL);
				_tmp26_ = _tmp25_;
				_g_free0 (_tmp24_);
				result = _tmp26_;
				_g_object_unref0 (t_event);
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_MODERATION_WARNING)))) {
		switch (0) {
			default:
			{
				GtkWidget* _tmp27_;
				_tmp27_ = tuba_api_notification_create_basic_card (self, "tuba-police-badge2-symbolic", _ ("Your account has received a moderation warning"), NULL);
				result = _tmp27_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label5) ? _tmp2_label5 : (_tmp2_label5 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_REPORT)))) {
		switch (0) {
			default:
			{
				TubaAPIAdminReport* _tmp28_;
				const gchar* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				GtkWidget* _tmp32_;
				GtkWidget* _tmp33_;
				_tmp28_ = self->priv->_report;
				_tmp29_ = self->priv->_created_at;
				_tmp30_ = tuba_api_admin_report_to_string (_tmp28_, _tmp29_);
				_tmp31_ = _tmp30_;
				_tmp32_ = tuba_api_notification_create_basic_card (self, "tuba-build-alt-symbolic", _tmp31_, NULL);
				_tmp33_ = _tmp32_;
				_g_free0 (_tmp31_);
				result = _tmp33_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label6) ? _tmp2_label6 : (_tmp2_label6 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ANNUAL_REPORT)))) {
		switch (0) {
			default:
			{
				gint _tmp34_ = 0;
				const gchar* _tmp35_;
				gint year = 0;
				gchar* _tmp41_;
				gchar* _tmp42_;
				gchar* _tmp43_;
				gchar* _tmp44_;
				gchar* _tmp45_;
				gchar* _tmp46_;
				GtkWidget* _tmp47_;
				GtkWidget* _tmp48_;
				_tmp35_ = self->priv->_created_at;
				if (_tmp35_ == NULL) {
					GDateTime* _tmp36_;
					GDateTime* _tmp37_;
					_tmp36_ = g_date_time_new_now_local ();
					_tmp37_ = _tmp36_;
					_tmp34_ = g_date_time_get_year (_tmp37_);
					_g_date_time_unref0 (_tmp37_);
				} else {
					const gchar* _tmp38_;
					GDateTime* _tmp39_;
					GDateTime* _tmp40_;
					_tmp38_ = self->priv->_created_at;
					_tmp39_ = g_date_time_new_from_iso8601 (_tmp38_, NULL);
					_tmp40_ = _tmp39_;
					_tmp34_ = g_date_time_get_year (_tmp40_);
					_g_date_time_unref0 (_tmp40_);
				}
				year = _tmp34_;
				_tmp41_ = g_strdup_printf ("%i", year);
				_tmp42_ = _tmp41_;
				_tmp43_ = g_strdup_printf (_ ("Your %s #FediWrapped is ready!"), _tmp42_);
				_tmp44_ = _tmp43_;
				_tmp45_ = g_strdup_printf ("<b>%s</b> %s", _tmp44_, _ ("Review your year's highlights and memorable moments on the Fediverse!"));
				_tmp46_ = _tmp45_;
				_tmp47_ = tuba_api_notification_create_basic_card (self, "tuba-birthday-symbolic", _tmp46_, NULL);
				_tmp48_ = _tmp47_;
				_g_free0 (_tmp46_);
				_g_free0 (_tmp44_);
				_g_free0 (_tmp42_);
				result = _tmp48_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label7) ? _tmp2_label7 : (_tmp2_label7 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_ADDED)))) {
		switch (0) {
			default:
			{
				TubaWidgetsCollectionRow* widget = NULL;
				TubaAPICollection* _tmp49_;
				TubaWidgetsCollectionRow* _tmp53_;
				GtkWidget* _tmp54_;
				widget = NULL;
				_tmp49_ = self->priv->_collection;
				if (_tmp49_ != NULL) {
					TubaAPICollection* _tmp50_;
					GtkWidget* _tmp51_;
					TubaWidgetsCollectionRow* _tmp52_;
					_tmp50_ = self->priv->_collection;
					_tmp51_ = tuba_widgetizable_to_widget ((TubaWidgetizable*) _tmp50_);
					_g_object_unref0 (widget);
					widget = G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, TUBA_WIDGETS_TYPE_COLLECTION_ROW, TubaWidgetsCollectionRow);
					_tmp52_ = widget;
					gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp52_, FALSE);
				}
				_tmp53_ = widget;
				_tmp54_ = tuba_api_notification_create_basic_card (self, "tuba-shapes-symbolic", _ ("You were added to a collection"), (GtkWidget*) _tmp53_);
				result = _tmp54_;
				_g_object_unref0 (widget);
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label8) ? _tmp2_label8 : (_tmp2_label8 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_EDITED)))) {
		switch (0) {
			default:
			{
				TubaWidgetsCollectionRow* widget = NULL;
				TubaAPICollection* _tmp55_;
				TubaWidgetsCollectionRow* _tmp59_;
				GtkWidget* _tmp60_;
				widget = NULL;
				_tmp55_ = self->priv->_collection;
				if (_tmp55_ != NULL) {
					TubaAPICollection* _tmp56_;
					GtkWidget* _tmp57_;
					TubaWidgetsCollectionRow* _tmp58_;
					_tmp56_ = self->priv->_collection;
					_tmp57_ = tuba_widgetizable_to_widget ((TubaWidgetizable*) _tmp56_);
					_g_object_unref0 (widget);
					widget = G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, TUBA_WIDGETS_TYPE_COLLECTION_ROW, TubaWidgetsCollectionRow);
					_tmp58_ = widget;
					gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp58_, FALSE);
				}
				_tmp59_ = widget;
				_tmp60_ = tuba_api_notification_create_basic_card (self, "tuba-shapes-symbolic", _ ("A collection you are a part of was edited"), (GtkWidget*) _tmp59_);
				result = _tmp60_;
				_g_object_unref0 (widget);
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				const gchar* _tmp61_;
				const gchar* _tmp63_;
				gchar* _tmp64_;
				gchar* _tmp65_;
				GtkWidget* _tmp66_;
				GtkWidget* _tmp67_;
				_tmp61_ = self->priv->_kind;
				if (_vala_string_array_contains (TUBA_INSTANCE_ACCOUNT_ALL_HANDLED_NOTIFICATION_TYPES, G_N_ELEMENTS (TUBA_INSTANCE_ACCOUNT_ALL_HANDLED_NOTIFICATION_TYPES), _tmp61_)) {
					TubaWidgetsNotification* _tmp62_;
					_tmp62_ = tuba_widgets_notification_new (self, TRUE);
					g_object_ref_sink (_tmp62_);
					result = (GtkWidget*) _tmp62_;
					return result;
				}
				_tmp63_ = self->priv->_kind;
				_tmp64_ = g_strdup_printf (_ ("Unknown notification type: %s"), _tmp63_);
				_tmp65_ = _tmp64_;
				_tmp66_ = tuba_api_notification_create_basic_card (self, "tuba-lightbulb-symbolic", _tmp65_, NULL);
				_tmp67_ = _tmp66_;
				_g_free0 (_tmp65_);
				result = _tmp67_;
				return result;
			}
		}
	}
}

static void
_tuba_widgetizable_open_tuba_widgets_list_box_row_wrapper_open (TubaWidgetsListBoxRowWrapper* _sender,
                                                                gpointer self)
{
	tuba_widgetizable_open ((TubaWidgetizable*) self);
}

static GtkWidget*
tuba_api_notification_create_basic_card (TubaAPINotification* self,
                                         const gchar* icon_name,
                                         const gchar* label,
                                         GtkWidget* extra_widget)
{
	GtkBox* box = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkBox* _tmp1_;
	GtkImage* _tmp2_ = NULL;
	GtkImage* _tmp3_;
	GtkBox* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	GtkLabel* _tmp7_ = NULL;
	GtkLabel* _tmp8_;
	TubaWidgetsListBoxRowWrapper* row = NULL;
	TubaWidgetsListBoxRowWrapper* _tmp9_;
	TubaWidgetsListBoxRowWrapper* _tmp18_;
	GtkWidget* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (icon_name != NULL, NULL);
	g_return_val_if_fail (label != NULL, NULL);
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 16);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp0_, 8);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp0_, 8);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp0_, 16);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp0_, 16);
	g_object_ref_sink (_tmp0_);
	box = _tmp0_;
	_tmp1_ = box;
	_tmp2_ = (GtkImage*) gtk_image_new_from_icon_name (icon_name);
	gtk_image_set_icon_size (_tmp2_, GTK_ICON_SIZE_LARGE);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	gtk_box_append (_tmp1_, (GtkWidget*) _tmp3_);
	_g_object_unref0 (_tmp3_);
	_tmp4_ = box;
	_tmp5_ = g_strdup ("title");
	_tmp6_ = g_new0 (gchar*, 1 + 1);
	_tmp6_[0] = _tmp5_;
	_tmp7_ = (GtkLabel*) gtk_label_new (label);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp7_, TRUE);
	gtk_label_set_xalign (_tmp7_, 0.0f);
	gtk_label_set_use_markup (_tmp7_, TRUE);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp7_, _tmp6_);
	_tmp6_ = (_vala_array_free (_tmp6_, 1, (GDestroyNotify) g_free), NULL);
	gtk_label_set_wrap (_tmp7_, TRUE);
	gtk_label_set_wrap_mode (_tmp7_, PANGO_WRAP_WORD_CHAR);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp7_, TRUE);
	g_object_ref_sink (_tmp7_);
	_tmp8_ = _tmp7_;
	gtk_box_append (_tmp4_, (GtkWidget*) _tmp8_);
	_g_object_unref0 (_tmp8_);
	_tmp9_ = tuba_widgets_list_box_row_wrapper_new ();
	g_object_ref_sink (_tmp9_);
	row = _tmp9_;
	if (extra_widget != NULL) {
		GtkBox* wrapper_box = NULL;
		GtkBox* _tmp10_;
		GtkBox* _tmp11_;
		GtkBox* _tmp12_;
		GtkBox* _tmp13_;
		TubaWidgetsListBoxRowWrapper* _tmp14_;
		GtkBox* _tmp15_;
		_tmp10_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
		g_object_ref_sink (_tmp10_);
		wrapper_box = _tmp10_;
		_tmp11_ = wrapper_box;
		_tmp12_ = box;
		gtk_box_append (_tmp11_, (GtkWidget*) _tmp12_);
		_tmp13_ = wrapper_box;
		gtk_box_append (_tmp13_, extra_widget);
		_tmp14_ = row;
		_tmp15_ = wrapper_box;
		gtk_list_box_row_set_child ((GtkListBoxRow*) _tmp14_, (GtkWidget*) _tmp15_);
		gtk_widget_set_margin_end (extra_widget, 12);
		gtk_widget_set_margin_start (extra_widget, 12);
		_g_object_unref0 (wrapper_box);
	} else {
		TubaWidgetsListBoxRowWrapper* _tmp16_;
		GtkBox* _tmp17_;
		_tmp16_ = row;
		_tmp17_ = box;
		gtk_list_box_row_set_child ((GtkListBoxRow*) _tmp16_, (GtkWidget*) _tmp17_);
	}
	_tmp18_ = row;
	g_signal_connect_object (_tmp18_, "open", (GCallback) _tuba_widgetizable_open_tuba_widgets_list_box_row_wrapper_open, (TubaWidgetizable*) self, 0);
	result = (GtkWidget*) row;
	_g_object_unref0 (box);
	return result;
}

static void
tuba_api_notification_real_to_toast_data_free (gpointer _data)
{
	TubaApiNotificationToToastData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->issuer);
	_g_object_unref0 (_data_->result);
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaApiNotificationToToastData, _data_);
}

static void
tuba_api_notification_real_to_toast (TubaAPINotification* self,
                                     TubaInstanceAccount* issuer,
                                     gint others,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_)
{
	TubaApiNotificationToToastData* _data_;
	TubaAPINotification* _tmp0_;
	TubaInstanceAccount* _tmp1_;
	g_return_if_fail (issuer != NULL);
	_data_ = g_slice_new0 (TubaApiNotificationToToastData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_api_notification_real_to_toast_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (issuer);
	_g_object_unref0 (_data_->issuer);
	_data_->issuer = _tmp1_;
	_data_->others = others;
	tuba_api_notification_real_to_toast_co (_data_);
}

static GNotification*
tuba_api_notification_real_to_toast_finish (TubaAPINotification* self,
                                            GAsyncResult* _res_)
{
	GNotification* result;
	TubaApiNotificationToToastData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

static glong
string_strnlen (gchar* str,
                glong maxlen)
{
	gchar* end = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	glong result;
	_tmp0_ = memchr (str, 0, (gsize) maxlen);
	end = _tmp0_;
	_tmp1_ = end;
	if (_tmp1_ == NULL) {
		result = maxlen;
		return result;
	} else {
		gchar* _tmp2_;
		_tmp2_ = end;
		result = (glong) (_tmp2_ - str);
		return result;
	}
}

static gchar*
string_substring (const gchar* self,
                  glong offset,
                  glong len)
{
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp3_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	if (offset >= ((glong) 0)) {
		_tmp0_ = len >= ((glong) 0);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		string_length = string_strnlen ((gchar*) self, offset + len);
	} else {
		gint _tmp1_;
		gint _tmp2_;
		_tmp1_ = strlen (self);
		_tmp2_ = _tmp1_;
		string_length = (glong) _tmp2_;
	}
	if (offset < ((glong) 0)) {
		offset = string_length + offset;
		g_return_val_if_fail (offset >= ((glong) 0), NULL);
	} else {
		g_return_val_if_fail (offset <= string_length, NULL);
	}
	if (len < ((glong) 0)) {
		len = string_length - offset;
	}
	g_return_val_if_fail ((offset + len) <= string_length, NULL);
	_tmp3_ = g_strndup (((gchar*) self) + offset, (gsize) len);
	result = _tmp3_;
	return result;
}

static gchar*
string_strip (const gchar* self)
{
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = g_strdup (self);
	_result_ = _tmp0_;
	g_strstrip (_result_);
	result = _result_;
	return result;
}

static GVariant*
_variant_new1 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new2 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new3 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new4 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new5 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new6 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new7 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new8 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new9 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static GVariant*
_variant_new10 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new11 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new12 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static void
tuba_api_notification_to_toast_ready (GObject* source_object,
                                      GAsyncResult* _res_,
                                      gpointer _user_data_)
{
	TubaApiNotificationToToastData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_api_notification_real_to_toast_co (_data_);
}

static gboolean
tuba_api_notification_real_to_toast_co (TubaApiNotificationToToastData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = tuba_accounts;
	_data_->_tmp1_ = tuba_account_store_get_active (_data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->should_show_buttons = _data_->issuer == _data_->_tmp2_;
	_data_->_tmp3_ = _data_->self->priv->_account;
	_data_->_tmp4_ = tuba_api_account_get_display_name (_data_->_tmp3_);
	_data_->_tmp5_ = _data_->_tmp4_;
	_data_->_tmp6_ = g_strdup (_data_->_tmp5_);
	_data_->kind_actor_name = _data_->_tmp6_;
	_data_->_tmp7_ = _data_->kind_actor_name;
	_data_->_tmp8_ = strlen (_data_->_tmp7_);
	_data_->_tmp9_ = _data_->_tmp8_;
	if (_data_->_tmp9_ > 20) {
		_data_->_tmp10_ = _data_->kind_actor_name;
		_data_->_tmp11_ = string_substring (_data_->_tmp10_, (glong) 0, (glong) 20);
		_data_->_tmp12_ = _data_->_tmp11_;
		_data_->_tmp13_ = string_strip (_data_->_tmp12_);
		_data_->_tmp14_ = _data_->_tmp13_;
		_data_->_tmp15_ = g_strconcat (_data_->_tmp14_, "…", NULL);
		_g_free0 (_data_->kind_actor_name);
		_data_->kind_actor_name = _data_->_tmp15_;
		_g_free0 (_data_->_tmp14_);
		_g_free0 (_data_->_tmp12_);
	} else {
		_data_->_tmp16_ = _data_->kind_actor_name;
		_data_->_tmp17_ = string_strip (_data_->_tmp16_);
		_data_->_tmp18_ = _data_->_tmp17_;
		_data_->_tmp19_ = strlen (_data_->_tmp18_);
		_data_->_tmp20_ = _data_->_tmp19_;
		_data_->_tmp21_ = _data_->_tmp20_ == 0;
		_g_free0 (_data_->_tmp18_);
		if (_data_->_tmp21_) {
			_data_->_tmp22_ = _data_->self->priv->_account;
			_data_->_tmp23_ = tuba_api_account_get_handle (_data_->_tmp22_);
			_data_->_tmp24_ = _data_->_tmp23_;
			_g_free0 (_data_->kind_actor_name);
			_data_->kind_actor_name = _data_->_tmp24_;
		}
	}
	if (_data_->others > 0) {
		_data_->_tmp25_ = _data_->self->priv->_account;
		_data_->_tmp26_ = tuba_api_account_get_display_name (_data_->_tmp25_);
		_data_->_tmp27_ = _data_->_tmp26_;
		_data_->_tmp28_ = g_strdup_printf (_ ("%s (& %d others)"), _data_->_tmp27_, _data_->others);
		_g_free0 (_data_->kind_actor_name);
		_data_->kind_actor_name = _data_->_tmp28_;
	}
	_data_->_tmp29_ = _data_->self->priv->_emoji;
	_data_->_tmp30_ = g_strdup (_data_->_tmp29_);
	_data_->other_data = _data_->_tmp30_;
	_data_->_tmp31_ = _data_->self->priv->_kind;
	if (g_strcmp0 (_data_->_tmp31_, TUBA_INSTANCE_ACCOUNT_KIND_ANNUAL_REPORT) == 0) {
		_data_->_tmp33_ = _data_->self->priv->_created_at;
		if (_data_->_tmp33_ == NULL) {
			_data_->_tmp34_ = g_date_time_new_now_local ();
			_data_->_tmp35_ = _data_->_tmp34_;
			_data_->_tmp32_ = g_date_time_get_year (_data_->_tmp35_);
			_g_date_time_unref0 (_data_->_tmp35_);
		} else {
			_data_->_tmp36_ = _data_->self->priv->_created_at;
			_data_->_tmp37_ = g_date_time_new_from_iso8601 (_data_->_tmp36_, NULL);
			_data_->_tmp38_ = _data_->_tmp37_;
			_data_->_tmp32_ = g_date_time_get_year (_data_->_tmp38_);
			_g_date_time_unref0 (_data_->_tmp38_);
		}
		_data_->year = _data_->_tmp32_;
		_data_->_tmp39_ = g_strdup_printf ("%i", _data_->year);
		_g_free0 (_data_->other_data);
		_data_->other_data = _data_->_tmp39_;
	}
	_data_->_tmp40_ = _data_->self->priv->_kind;
	_data_->_tmp41_ = _data_->kind_actor_name;
	_data_->_tmp42_ = _data_->other_data;
	memset (&_data_->_tmp43_, 0, sizeof (TubaInstanceAccountKind));
	tuba_instance_account_describe_kind (_data_->issuer, _data_->_tmp40_, &_data_->_tmp43_, _data_->_tmp41_, NULL, _data_->_tmp42_);
	tuba_instance_account_kind_destroy (&_data_->res_kind);
	_data_->res_kind = _data_->_tmp43_;
	_data_->_tmp44_ = _data_->res_kind;
	_data_->_tmp45_ = _data_->_tmp44_.description;
	_data_->_tmp46_ = g_notification_new (_data_->_tmp45_);
	_data_->toast = _data_->_tmp46_;
	_data_->_tmp47_ = _data_->self->priv->_status;
	if (_data_->_tmp47_ != NULL) {
		_data_->_tmp50_ = _data_->self->priv->_status;
		_data_->_tmp51_ = tuba_api_status_get_spoiler_text (_data_->_tmp50_);
		_data_->_tmp52_ = _data_->_tmp51_;
		if (_data_->_tmp52_ != NULL) {
			_data_->_tmp53_ = _data_->self->priv->_status;
			_data_->_tmp54_ = tuba_api_status_get_spoiler_text (_data_->_tmp53_);
			_data_->_tmp55_ = _data_->_tmp54_;
			_data_->_tmp49_ = g_strcmp0 (_data_->_tmp55_, "") != 0;
		} else {
			_data_->_tmp49_ = FALSE;
		}
		if (_data_->_tmp49_) {
			_data_->_tmp56_ = tuba_settings;
			_data_->_tmp57_ = tuba_settings_get_show_spoilers (_data_->_tmp56_);
			_data_->_tmp58_ = _data_->_tmp57_;
			_data_->_tmp48_ = !_data_->_tmp58_;
		} else {
			_data_->_tmp48_ = FALSE;
		}
		if (_data_->_tmp48_) {
			_data_->_tmp59_ = _data_->toast;
			_data_->_tmp60_ = _data_->self->priv->_status;
			_data_->_tmp61_ = tuba_api_status_get_spoiler_text (_data_->_tmp60_);
			_data_->_tmp62_ = _data_->_tmp61_;
			_data_->_tmp63_ = g_strdup_printf ("%s: %s", _ ("Content Warning"), _data_->_tmp62_);
			_data_->_tmp64_ = _data_->_tmp63_;
			g_notification_set_body (_data_->_tmp59_, _data_->_tmp64_);
			_g_free0 (_data_->_tmp64_);
		} else {
			_data_->_tmp65_ = _data_->toast;
			_data_->_tmp66_ = _data_->self->priv->_status;
			_data_->_tmp67_ = tuba_api_status_get_content (_data_->_tmp66_);
			_data_->_tmp68_ = _data_->_tmp67_;
			_data_->_tmp69_ = tuba_utils_htmlx_remove_tags (_data_->_tmp68_);
			_data_->_tmp70_ = _data_->_tmp69_;
			g_notification_set_body (_data_->_tmp65_, _data_->_tmp70_);
			_g_free0 (_data_->_tmp70_);
		}
	}
	if (_data_->should_show_buttons) {
		static GQuark _tmp73_label0 = 0;
		static GQuark _tmp73_label1 = 0;
		static GQuark _tmp73_label2 = 0;
		static GQuark _tmp73_label3 = 0;
		static GQuark _tmp73_label4 = 0;
		static GQuark _tmp73_label5 = 0;
		static GQuark _tmp73_label6 = 0;
		static GQuark _tmp73_label7 = 0;
		static GQuark _tmp97_label0 = 0;
		static GQuark _tmp97_label1 = 0;
		static GQuark _tmp97_label2 = 0;
		_data_->_tmp71_ = _data_->self->priv->_kind;
		_data_->_tmp74_ = 0U;
		_data_->_tmp72_ = _data_->_tmp71_;
		_data_->_tmp74_ = (NULL == _data_->_tmp72_) ? 0 : g_quark_from_string (_data_->_tmp72_);
		if (((((_data_->_tmp74_ == ((0 != _tmp73_label0) ? _tmp73_label0 : (_tmp73_label0 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_SEVERED_RELATIONSHIPS)))) || (_data_->_tmp74_ == ((0 != _tmp73_label1) ? _tmp73_label1 : (_tmp73_label1 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_REPORT))))) || (_data_->_tmp74_ == ((0 != _tmp73_label2) ? _tmp73_label2 : (_tmp73_label2 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP))))) || (_data_->_tmp74_ == ((0 != _tmp73_label3) ? _tmp73_label3 : (_tmp73_label3 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ANNUAL_REPORT))))) || (_data_->_tmp74_ == ((0 != _tmp73_label4) ? _tmp73_label4 : (_tmp73_label4 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_MODERATION_WARNING))))) {
			switch (0) {
				default:
				{
					_data_->_tmp75_ = _data_->toast;
					g_notification_set_default_action (_data_->_tmp75_, "app.goto-notifications");
					break;
				}
			}
		} else if (_data_->_tmp74_ == ((0 != _tmp73_label5) ? _tmp73_label5 : (_tmp73_label5 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST)))) {
			switch (0) {
				default:
				{
					_data_->_tmp76_ = _data_->toast;
					g_notification_set_default_action (_data_->_tmp76_, "app.open-follow-requests");
					break;
				}
			}
		} else if ((_data_->_tmp74_ == ((0 != _tmp73_label6) ? _tmp73_label6 : (_tmp73_label6 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_ADDED)))) || (_data_->_tmp74_ == ((0 != _tmp73_label7) ? _tmp73_label7 : (_tmp73_label7 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_COLLECTION_EDITED))))) {
			switch (0) {
				default:
				{
					_data_->_tmp77_ = _data_->toast;
					g_notification_set_default_action (_data_->_tmp77_, "app.open-collections");
					break;
				}
			}
		} else {
			switch (0) {
				default:
				{
					_data_->_tmp78_ = _data_->self->priv->_account;
					_data_->_tmp79_ = tuba_api_account_get_url (_data_->_tmp78_);
					_data_->_tmp80_ = _data_->_tmp79_;
					_data_->_tmp81_ = g_strdup (_data_->_tmp80_);
					_data_->var_string = _data_->_tmp81_;
					_data_->_tmp83_ = _data_->self->priv->_status;
					if (_data_->_tmp83_ != NULL) {
						_data_->_tmp84_ = _data_->self->priv->_status;
						_data_->_tmp85_ = tuba_api_status_get_url (_data_->_tmp84_);
						_data_->_tmp86_ = _data_->_tmp85_;
						_data_->_tmp87_ = _data_->_tmp86_;
						_data_->_tmp82_ = _data_->_tmp87_ != NULL;
						_g_free0 (_data_->_tmp87_);
					} else {
						_data_->_tmp82_ = FALSE;
					}
					if (_data_->_tmp82_) {
						_data_->_tmp88_ = _data_->self->priv->_status;
						_data_->_tmp89_ = tuba_api_status_get_url (_data_->_tmp88_);
						_data_->_tmp90_ = _data_->_tmp89_;
						_g_free0 (_data_->var_string);
						_data_->var_string = _data_->_tmp90_;
					}
					_data_->_tmp91_ = _data_->toast;
					_data_->_tmp92_ = _data_->var_string;
					_data_->_tmp93_ = g_variant_new_string (_data_->_tmp92_);
					g_variant_ref_sink (_data_->_tmp93_);
					_data_->_tmp94_ = _data_->_tmp93_;
					g_notification_set_default_action_and_target_value (_data_->_tmp91_, "app.open-status-url", _data_->_tmp94_);
					_g_variant_unref0 (_data_->_tmp94_);
					_g_free0 (_data_->var_string);
					break;
				}
			}
		}
		_data_->_tmp95_ = _data_->self->priv->_kind;
		_data_->_tmp98_ = 0U;
		_data_->_tmp96_ = _data_->_tmp95_;
		_data_->_tmp98_ = (NULL == _data_->_tmp96_) ? 0 : g_quark_from_string (_data_->_tmp96_);
		if (_data_->_tmp98_ == ((0 != _tmp97_label0) ? _tmp97_label0 : (_tmp97_label0 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_MENTION)))) {
			switch (0) {
				default:
				{
					_data_->_tmp99_ = _data_->self->priv->_status;
					if (_data_->_tmp99_ != NULL) {
						_data_->_tmp100_ = _data_->toast;
						_data_->_tmp101_ = tuba_accounts;
						_data_->_tmp102_ = tuba_account_store_get_active (_data_->_tmp101_);
						_data_->_tmp103_ = _data_->_tmp102_;
						_data_->_tmp104_ = tuba_api_account_get_id ((TubaAPIAccount*) _data_->_tmp103_);
						_data_->_tmp105_ = _data_->_tmp104_;
						_data_->_tmp106_ = _variant_new1 (_data_->_tmp105_);
						_data_->_tmp107_ = _data_->self->priv->_status;
						_data_->_tmp108_ = tuba_api_status_get_uri (_data_->_tmp107_);
						_data_->_tmp109_ = _data_->_tmp108_;
						_data_->_tmp110_ = _variant_new2 (_data_->_tmp109_);
						_data_->_tmp111_ = g_new0 (GVariant*, 2 + 1);
						_data_->_tmp111_[0] = _data_->_tmp106_;
						_data_->_tmp111_[1] = _data_->_tmp110_;
						_data_->_tmp112_ = _data_->_tmp111_;
						_data_->_tmp112__length1 = 2;
						_data_->_tmp113_ = g_variant_new_tuple (_data_->_tmp112_, 2);
						g_variant_ref_sink (_data_->_tmp113_);
						_data_->_tmp114_ = _data_->_tmp113_;
						g_notification_add_button_with_target_value (_data_->_tmp100_, _ ("Reply…"), "app.reply-to-status-uri", _data_->_tmp114_);
						_g_variant_unref0 (_data_->_tmp114_);
						_data_->_tmp112_ = (_vala_array_free (_data_->_tmp112_, _data_->_tmp112__length1, (GDestroyNotify) g_variant_unref), NULL);
					}
					break;
				}
			}
		} else if (_data_->_tmp98_ == ((0 != _tmp97_label1) ? _tmp97_label1 : (_tmp97_label1 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW)))) {
			switch (0) {
				default:
				{
					_data_->_tmp115_ = _data_->toast;
					_data_->_tmp116_ = tuba_accounts;
					_data_->_tmp117_ = tuba_account_store_get_active (_data_->_tmp116_);
					_data_->_tmp118_ = _data_->_tmp117_;
					_data_->_tmp119_ = tuba_api_account_get_id ((TubaAPIAccount*) _data_->_tmp118_);
					_data_->_tmp120_ = _data_->_tmp119_;
					_data_->_tmp121_ = _variant_new3 (_data_->_tmp120_);
					_data_->_tmp122_ = _data_->self->priv->_account;
					_data_->_tmp123_ = tuba_api_account_get_id (_data_->_tmp122_);
					_data_->_tmp124_ = _data_->_tmp123_;
					_data_->_tmp125_ = _variant_new4 (_data_->_tmp124_);
					_data_->_tmp126_ = g_new0 (GVariant*, 2 + 1);
					_data_->_tmp126_[0] = _data_->_tmp121_;
					_data_->_tmp126_[1] = _data_->_tmp125_;
					_data_->_tmp127_ = _data_->_tmp126_;
					_data_->_tmp127__length1 = 2;
					_data_->_tmp128_ = g_variant_new_tuple (_data_->_tmp127_, 2);
					g_variant_ref_sink (_data_->_tmp128_);
					_data_->_tmp129_ = _data_->_tmp128_;
					g_notification_add_button_with_target_value (_data_->_tmp115_, _ ("Remove from Followers"), "app.remove-from-followers", _data_->_tmp129_);
					_g_variant_unref0 (_data_->_tmp129_);
					_data_->_tmp127_ = (_vala_array_free (_data_->_tmp127_, _data_->_tmp127__length1, (GDestroyNotify) g_variant_unref), NULL);
					_data_->_tmp130_ = _data_->toast;
					_data_->_tmp131_ = tuba_accounts;
					_data_->_tmp132_ = tuba_account_store_get_active (_data_->_tmp131_);
					_data_->_tmp133_ = _data_->_tmp132_;
					_data_->_tmp134_ = tuba_api_account_get_id ((TubaAPIAccount*) _data_->_tmp133_);
					_data_->_tmp135_ = _data_->_tmp134_;
					_data_->_tmp136_ = _variant_new5 (_data_->_tmp135_);
					_data_->_tmp137_ = _data_->self->priv->_account;
					_data_->_tmp138_ = tuba_api_account_get_id (_data_->_tmp137_);
					_data_->_tmp139_ = _data_->_tmp138_;
					_data_->_tmp140_ = _variant_new6 (_data_->_tmp139_);
					_data_->_tmp141_ = g_new0 (GVariant*, 2 + 1);
					_data_->_tmp141_[0] = _data_->_tmp136_;
					_data_->_tmp141_[1] = _data_->_tmp140_;
					_data_->_tmp142_ = _data_->_tmp141_;
					_data_->_tmp142__length1 = 2;
					_data_->_tmp143_ = g_variant_new_tuple (_data_->_tmp142_, 2);
					g_variant_ref_sink (_data_->_tmp143_);
					_data_->_tmp144_ = _data_->_tmp143_;
					g_notification_add_button_with_target_value (_data_->_tmp130_, _ ("Follow Back"), "app.follow-back", _data_->_tmp144_);
					_g_variant_unref0 (_data_->_tmp144_);
					_data_->_tmp142_ = (_vala_array_free (_data_->_tmp142_, _data_->_tmp142__length1, (GDestroyNotify) g_variant_unref), NULL);
					break;
				}
			}
		} else if (_data_->_tmp98_ == ((0 != _tmp97_label2) ? _tmp97_label2 : (_tmp97_label2 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST)))) {
			switch (0) {
				default:
				{
					_data_->_tmp145_ = _data_->toast;
					_data_->_tmp146_ = tuba_accounts;
					_data_->_tmp147_ = tuba_account_store_get_active (_data_->_tmp146_);
					_data_->_tmp148_ = _data_->_tmp147_;
					_data_->_tmp149_ = tuba_api_account_get_id ((TubaAPIAccount*) _data_->_tmp148_);
					_data_->_tmp150_ = _data_->_tmp149_;
					_data_->_tmp151_ = _variant_new7 (_data_->_tmp150_);
					_data_->_tmp152_ = _data_->self->priv->_account;
					_data_->_tmp153_ = tuba_api_account_get_id (_data_->_tmp152_);
					_data_->_tmp154_ = _data_->_tmp153_;
					_data_->_tmp155_ = _variant_new8 (_data_->_tmp154_);
					_data_->_tmp156_ = _variant_new9 (FALSE);
					_data_->_tmp157_ = g_new0 (GVariant*, 3 + 1);
					_data_->_tmp157_[0] = _data_->_tmp151_;
					_data_->_tmp157_[1] = _data_->_tmp155_;
					_data_->_tmp157_[2] = _data_->_tmp156_;
					_data_->_tmp158_ = _data_->_tmp157_;
					_data_->_tmp158__length1 = 3;
					_data_->_tmp159_ = g_variant_new_tuple (_data_->_tmp158_, 3);
					g_variant_ref_sink (_data_->_tmp159_);
					_data_->_tmp160_ = _data_->_tmp159_;
					g_notification_add_button_with_target_value (_data_->_tmp145_, _ ("Decline"), "app.answer-follow-request", _data_->_tmp160_);
					_g_variant_unref0 (_data_->_tmp160_);
					_data_->_tmp158_ = (_vala_array_free (_data_->_tmp158_, _data_->_tmp158__length1, (GDestroyNotify) g_variant_unref), NULL);
					_data_->_tmp161_ = _data_->toast;
					_data_->_tmp162_ = tuba_accounts;
					_data_->_tmp163_ = tuba_account_store_get_active (_data_->_tmp162_);
					_data_->_tmp164_ = _data_->_tmp163_;
					_data_->_tmp165_ = tuba_api_account_get_id ((TubaAPIAccount*) _data_->_tmp164_);
					_data_->_tmp166_ = _data_->_tmp165_;
					_data_->_tmp167_ = _variant_new10 (_data_->_tmp166_);
					_data_->_tmp168_ = _data_->self->priv->_account;
					_data_->_tmp169_ = tuba_api_account_get_id (_data_->_tmp168_);
					_data_->_tmp170_ = _data_->_tmp169_;
					_data_->_tmp171_ = _variant_new11 (_data_->_tmp170_);
					_data_->_tmp172_ = _variant_new12 (TRUE);
					_data_->_tmp173_ = g_new0 (GVariant*, 3 + 1);
					_data_->_tmp173_[0] = _data_->_tmp167_;
					_data_->_tmp173_[1] = _data_->_tmp171_;
					_data_->_tmp173_[2] = _data_->_tmp172_;
					_data_->_tmp174_ = _data_->_tmp173_;
					_data_->_tmp174__length1 = 3;
					_data_->_tmp175_ = g_variant_new_tuple (_data_->_tmp174_, 3);
					g_variant_ref_sink (_data_->_tmp175_);
					_data_->_tmp176_ = _data_->_tmp175_;
					g_notification_add_button_with_target_value (_data_->_tmp161_, _ ("Accept"), "app.answer-follow-request", _data_->_tmp176_);
					_g_variant_unref0 (_data_->_tmp176_);
					_data_->_tmp174_ = (_vala_array_free (_data_->_tmp174_, _data_->_tmp174__length1, (GDestroyNotify) g_variant_unref), NULL);
					break;
				}
			}
		}
	}
	_data_->icon = NULL;
	if (tuba_is_flatpak) {
		_data_->_tmp177_ = _data_->self->priv->_account;
		_data_->_tmp178_ = tuba_api_account_get_avatar (_data_->_tmp177_);
		_data_->_tmp179_ = _data_->_tmp178_;
		_data_->_state_ = 1;
		tuba_helper_image_request_bytes (_data_->_tmp179_, tuba_api_notification_to_toast_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp180_ = tuba_helper_image_request_bytes_finish (_data_->_res_);
		_data_->avatar_bytes = _data_->_tmp180_;
		_data_->_tmp181_ = _data_->avatar_bytes;
		if (_data_->_tmp181_ != NULL) {
			_data_->_tmp182_ = _data_->avatar_bytes;
			_data_->_tmp183_ = (GBytesIcon*) g_bytes_icon_new (_data_->_tmp182_);
			_g_object_unref0 (_data_->icon);
			_data_->icon = (GIcon*) _data_->_tmp183_;
		}
		_g_bytes_unref0 (_data_->avatar_bytes);
	} else {
		_data_->_tmp184_ = _data_->self->priv->_account;
		_data_->_tmp185_ = tuba_api_account_get_avatar (_data_->_tmp184_);
		_data_->_tmp186_ = _data_->_tmp185_;
		_data_->_tmp187_ = g_file_new_for_uri (_data_->_tmp186_);
		_data_->icon_file = _data_->_tmp187_;
		_data_->_tmp188_ = _data_->icon_file;
		_data_->_tmp189_ = (GFileIcon*) g_file_icon_new (_data_->_tmp188_);
		_g_object_unref0 (_data_->icon);
		_data_->icon = (GIcon*) _data_->_tmp189_;
		_g_object_unref0 (_data_->icon_file);
	}
	_data_->_tmp190_ = _data_->icon;
	if (_data_->_tmp190_ != NULL) {
		_data_->_tmp191_ = _data_->toast;
		_data_->_tmp192_ = _data_->icon;
		g_notification_set_icon (_data_->_tmp191_, _data_->_tmp192_);
	}
	_data_->result = _data_->toast;
	_g_object_unref0 (_data_->icon);
	_g_free0 (_data_->other_data);
	_g_free0 (_data_->kind_actor_name);
	tuba_instance_account_kind_destroy (&_data_->res_kind);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

void
tuba_api_notification_to_toast (TubaAPINotification* self,
                                TubaInstanceAccount* issuer,
                                gint others,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_)
{
	TubaAPINotificationClass* _klass_;
	_klass_ = TUBA_API_NOTIFICATION_GET_CLASS (self);
	if (_klass_->to_toast) {
		_klass_->to_toast (self, issuer, others, _callback_, _user_data_);
	}
}

GNotification*
tuba_api_notification_to_toast_finish (TubaAPINotification* self,
                                       GAsyncResult* _res_)
{
	TubaAPINotificationClass* _klass_;
	_klass_ = TUBA_API_NOTIFICATION_GET_CLASS (self);
	if (_klass_->to_toast_finish) {
		return _klass_->to_toast_finish (self, _res_);
	}
	return NULL;
}

TubaAPINotification*
tuba_api_notification_construct (GType object_type)
{
	TubaAPINotification * self = NULL;
	self = (TubaAPINotification*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINotification*
tuba_api_notification_new (void)
{
	return tuba_api_notification_construct (TUBA_API_TYPE_NOTIFICATION);
}

const gchar*
tuba_api_notification_get_id (TubaAPINotification* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_id (TubaAPINotification* self,
                              const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_ID_PROPERTY]);
	}
}

TubaAPIAccount*
tuba_api_notification_get_account (TubaAPINotification* self)
{
	TubaAPIAccount* result;
	TubaAPIAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_account;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_account (TubaAPINotification* self,
                                   TubaAPIAccount* value)
{
	TubaAPIAccount* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_account (self);
	if (old_value != value) {
		TubaAPIAccount* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_account);
		self->priv->_account = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_ACCOUNT_PROPERTY]);
	}
}

const gchar*
tuba_api_notification_get_kind (TubaAPINotification* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_kind;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_kind (TubaAPINotification* self,
                                const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_kind (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_kind);
		self->priv->_kind = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_KIND_PROPERTY]);
	}
}

const gchar*
tuba_api_notification_get_created_at (TubaAPINotification* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_created_at;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_created_at (TubaAPINotification* self,
                                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_created_at (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_created_at);
		self->priv->_created_at = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_CREATED_AT_PROPERTY]);
	}
}

TubaAPIStatus*
tuba_api_notification_get_status (TubaAPINotification* self)
{
	TubaAPIStatus* result;
	TubaAPIStatus* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_status;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_status (TubaAPINotification* self,
                                  TubaAPIStatus* value)
{
	TubaAPIStatus* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_status (self);
	if (old_value != value) {
		TubaAPIStatus* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_status);
		self->priv->_status = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_STATUS_PROPERTY]);
	}
}

const gchar*
tuba_api_notification_get_emoji (TubaAPINotification* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_emoji;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_emoji (TubaAPINotification* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_emoji (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_emoji);
		self->priv->_emoji = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_EMOJI_PROPERTY]);
	}
}

const gchar*
tuba_api_notification_get_emoji_url (TubaAPINotification* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_emoji_url;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_emoji_url (TubaAPINotification* self,
                                     const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_emoji_url (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_emoji_url);
		self->priv->_emoji_url = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_EMOJI_URL_PROPERTY]);
	}
}

TubaAPIAdminReport*
tuba_api_notification_get_report (TubaAPINotification* self)
{
	TubaAPIAdminReport* result;
	TubaAPIAdminReport* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_report;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_report (TubaAPINotification* self,
                                  TubaAPIAdminReport* value)
{
	TubaAPIAdminReport* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_report (self);
	if (old_value != value) {
		TubaAPIAdminReport* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_report);
		self->priv->_report = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_REPORT_PROPERTY]);
	}
}

TubaAPINotificationModerationWarning*
tuba_api_notification_get_moderation_warning (TubaAPINotification* self)
{
	TubaAPINotificationModerationWarning* result;
	TubaAPINotificationModerationWarning* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_moderation_warning;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_moderation_warning (TubaAPINotification* self,
                                              TubaAPINotificationModerationWarning* value)
{
	TubaAPINotificationModerationWarning* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_moderation_warning (self);
	if (old_value != value) {
		TubaAPINotificationModerationWarning* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_moderation_warning);
		self->priv->_moderation_warning = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_MODERATION_WARNING_PROPERTY]);
	}
}

const gchar*
tuba_api_notification_get_group_key (TubaAPINotification* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_group_key;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_group_key (TubaAPINotification* self,
                                     const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_group_key (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_group_key);
		self->priv->_group_key = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_GROUP_KEY_PROPERTY]);
	}
}

TubaAPICollection*
tuba_api_notification_get_collection (TubaAPINotification* self)
{
	TubaAPICollection* result;
	TubaAPICollection* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_collection;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_collection (TubaAPINotification* self,
                                      TubaAPICollection* value)
{
	TubaAPICollection* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_collection (self);
	if (old_value != value) {
		TubaAPICollection* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_collection);
		self->priv->_collection = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_COLLECTION_PROPERTY]);
	}
}

TubaAPINotificationRelationshipSeveranceEvent*
tuba_api_notification_get_event (TubaAPINotification* self)
{
	TubaAPINotificationRelationshipSeveranceEvent* result;
	TubaAPINotificationRelationshipSeveranceEvent* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_event;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_event (TubaAPINotification* self,
                                 TubaAPINotificationRelationshipSeveranceEvent* value)
{
	TubaAPINotificationRelationshipSeveranceEvent* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_event (self);
	if (old_value != value) {
		TubaAPINotificationRelationshipSeveranceEvent* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_event);
		self->priv->_event = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_EVENT_PROPERTY]);
	}
}

TubaAPINotificationRelationshipSeveranceEvent*
tuba_api_notification_get_relationship_severance_event (TubaAPINotification* self)
{
	TubaAPINotificationRelationshipSeveranceEvent* result;
	TubaAPINotificationRelationshipSeveranceEvent* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_relationship_severance_event;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_set_relationship_severance_event (TubaAPINotification* self,
                                                        TubaAPINotificationRelationshipSeveranceEvent* value)
{
	TubaAPINotificationRelationshipSeveranceEvent* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_get_relationship_severance_event (self);
	if (old_value != value) {
		TubaAPINotificationRelationshipSeveranceEvent* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_relationship_severance_event);
		self->priv->_relationship_severance_event = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_PROPERTY]);
	}
}

static inline gpointer
tuba_api_notification_relationship_severance_event_get_instance_private (TubaAPINotificationRelationshipSeveranceEvent* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINotificationRelationshipSeveranceEvent_private_offset);
}

gchar*
tuba_api_notification_relationship_severance_event_to_string (TubaAPINotificationRelationshipSeveranceEvent* self)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
	static GQuark _tmp2_label0 = 0;
	static GQuark _tmp2_label1 = 0;
	static GQuark _tmp2_label2 = 0;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_kind;
	_tmp1_ = _tmp0_;
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("user_domain_block")))) {
		switch (0) {
			default:
			{
				gint64 _tmp4_;
				const gchar* _tmp5_;
				gchar* _tmp6_;
				gchar* _tmp7_;
				gint64 _tmp8_;
				gchar* _tmp9_;
				gchar* _tmp10_;
				gint64 _tmp11_;
				gchar* _tmp12_;
				gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
				_tmp4_ = self->priv->_following_count;
				_tmp5_ = self->priv->_target_name;
				_tmp6_ = g_strdup_printf ("<b>%s</b>", _tmp5_);
				_tmp7_ = _tmp6_;
				_tmp8_ = self->priv->_followers_count;
				_tmp9_ = g_strdup_printf ("<b>%lld</b>", _tmp8_);
				_tmp10_ = _tmp9_;
				_tmp11_ = self->priv->_following_count;
				_tmp12_ = g_strdup_printf ("<b>%lld</b>", _tmp11_);
				_tmp13_ = _tmp12_;
				_tmp14_ = g_strdup_printf (ngettext ("You have blocked %s, removing %s of your followers and %s account you " \
"follow.", "You have blocked %s, removing %s of your followers and %s accounts you" \
" follow.", (gulong) _tmp4_), _tmp7_, _tmp10_, _tmp13_);
				_tmp15_ = _tmp14_;
				_g_free0 (_tmp13_);
				_g_free0 (_tmp10_);
				_g_free0 (_tmp7_);
				result = _tmp15_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("domain_block")))) {
		switch (0) {
			default:
			{
				gint64 _tmp16_;
				const gchar* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
				gint64 _tmp20_;
				gchar* _tmp21_;
				gchar* _tmp22_;
				gint64 _tmp23_;
				gchar* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				gchar* _tmp27_;
				_tmp16_ = self->priv->_following_count;
				_tmp17_ = self->priv->_target_name;
				_tmp18_ = g_strdup_printf ("<b>%s</b>", _tmp17_);
				_tmp19_ = _tmp18_;
				_tmp20_ = self->priv->_followers_count;
				_tmp21_ = g_strdup_printf ("<b>%lld</b>", _tmp20_);
				_tmp22_ = _tmp21_;
				_tmp23_ = self->priv->_following_count;
				_tmp24_ = g_strdup_printf ("<b>%lld</b>", _tmp23_);
				_tmp25_ = _tmp24_;
				_tmp26_ = g_strdup_printf (ngettext ("An admin has blocked %s, including %s of your followers and %s account" \
" you follow.", "An admin has blocked %s, including %s of your followers and %s account" \
"s you follow.", (gulong) _tmp16_), _tmp19_, _tmp22_, _tmp25_);
				_tmp27_ = _tmp26_;
				_g_free0 (_tmp25_);
				_g_free0 (_tmp22_);
				_g_free0 (_tmp19_);
				result = _tmp27_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("account_suspension")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp28_;
				gchar* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				gchar* _tmp32_;
				_tmp28_ = self->priv->_target_name;
				_tmp29_ = g_strdup_printf ("<b>%s</b>", _tmp28_);
				_tmp30_ = _tmp29_;
				_tmp31_ = g_strdup_printf (_ ("An admin has suspended %s, which means you can no longer receive updat" \
"es from them or interact with them."), _tmp30_);
				_tmp32_ = _tmp31_;
				_g_free0 (_tmp30_);
				result = _tmp32_;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
}

TubaAPINotificationRelationshipSeveranceEvent*
tuba_api_notification_relationship_severance_event_construct (GType object_type)
{
	TubaAPINotificationRelationshipSeveranceEvent * self = NULL;
	self = (TubaAPINotificationRelationshipSeveranceEvent*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINotificationRelationshipSeveranceEvent*
tuba_api_notification_relationship_severance_event_new (void)
{
	return tuba_api_notification_relationship_severance_event_construct (TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT);
}

const gchar*
tuba_api_notification_relationship_severance_event_get_kind (TubaAPINotificationRelationshipSeveranceEvent* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_kind;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_relationship_severance_event_set_kind (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_relationship_severance_event_get_kind (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_kind);
		self->priv->_kind = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_KIND_PROPERTY]);
	}
}

const gchar*
tuba_api_notification_relationship_severance_event_get_target_name (TubaAPINotificationRelationshipSeveranceEvent* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_target_name;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_relationship_severance_event_set_target_name (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                    const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_relationship_severance_event_get_target_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_target_name);
		self->priv->_target_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_TARGET_NAME_PROPERTY]);
	}
}

gint64
tuba_api_notification_relationship_severance_event_get_relationships_count (TubaAPINotificationRelationshipSeveranceEvent* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_relationships_count;
	return result;
}

void
tuba_api_notification_relationship_severance_event_set_relationships_count (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                            gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_relationship_severance_event_get_relationships_count (self);
	if (old_value != value) {
		self->priv->_relationships_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_RELATIONSHIPS_COUNT_PROPERTY]);
	}
}

gint64
tuba_api_notification_relationship_severance_event_get_followers_count (TubaAPINotificationRelationshipSeveranceEvent* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_followers_count;
	return result;
}

void
tuba_api_notification_relationship_severance_event_set_followers_count (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                        gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_relationship_severance_event_get_followers_count (self);
	if (old_value != value) {
		self->priv->_followers_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWERS_COUNT_PROPERTY]);
	}
}

gint64
tuba_api_notification_relationship_severance_event_get_following_count (TubaAPINotificationRelationshipSeveranceEvent* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_following_count;
	return result;
}

void
tuba_api_notification_relationship_severance_event_set_following_count (TubaAPINotificationRelationshipSeveranceEvent* self,
                                                                        gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_relationship_severance_event_get_following_count (self);
	if (old_value != value) {
		self->priv->_following_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWING_COUNT_PROPERTY]);
	}
}

static void
tuba_api_notification_relationship_severance_event_class_init (TubaAPINotificationRelationshipSeveranceEventClass * klass,
                                                               gpointer klass_data)
{
	tuba_api_notification_relationship_severance_event_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINotificationRelationshipSeveranceEvent_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_notification_relationship_severance_event_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_notification_relationship_severance_event_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_notification_relationship_severance_event_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_KIND_PROPERTY, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_KIND_PROPERTY] = g_param_spec_string ("kind", "kind", "kind", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_TARGET_NAME_PROPERTY, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_TARGET_NAME_PROPERTY] = g_param_spec_string ("target-name", "target-name", "target-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_RELATIONSHIPS_COUNT_PROPERTY, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_RELATIONSHIPS_COUNT_PROPERTY] = g_param_spec_int64 ("relationships-count", "relationships-count", "relationships-count", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWERS_COUNT_PROPERTY, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWERS_COUNT_PROPERTY] = g_param_spec_int64 ("followers-count", "followers-count", "followers-count", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWING_COUNT_PROPERTY, tuba_api_notification_relationship_severance_event_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWING_COUNT_PROPERTY] = g_param_spec_int64 ("following-count", "following-count", "following-count", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_notification_relationship_severance_event_instance_init (TubaAPINotificationRelationshipSeveranceEvent * self,
                                                                  gpointer klass)
{
	gchar* _tmp0_;
	self->priv = tuba_api_notification_relationship_severance_event_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_target_name = _tmp0_;
	self->priv->_relationships_count = (gint64) 0;
	self->priv->_followers_count = (gint64) 0;
	self->priv->_following_count = (gint64) 0;
}

static void
tuba_api_notification_relationship_severance_event_finalize (GObject * obj)
{
	TubaAPINotificationRelationshipSeveranceEvent * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, TubaAPINotificationRelationshipSeveranceEvent);
	_g_free0 (self->priv->_kind);
	_g_free0 (self->priv->_target_name);
	G_OBJECT_CLASS (tuba_api_notification_relationship_severance_event_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_notification_relationship_severance_event_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINotificationRelationshipSeveranceEventClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_notification_relationship_severance_event_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINotificationRelationshipSeveranceEvent), 0, (GInstanceInitFunc) tuba_api_notification_relationship_severance_event_instance_init, NULL };
	GType tuba_api_notification_relationship_severance_event_type_id;
	tuba_api_notification_relationship_severance_event_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINotificationRelationshipSeveranceEvent", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINotificationRelationshipSeveranceEvent_private_offset = g_type_add_instance_private (tuba_api_notification_relationship_severance_event_type_id, sizeof (TubaAPINotificationRelationshipSeveranceEventPrivate));
	return tuba_api_notification_relationship_severance_event_type_id;
}

GType
tuba_api_notification_relationship_severance_event_get_type (void)
{
	static GType tuba_api_notification_relationship_severance_event_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_notification_relationship_severance_event_type_id__once)) {
		GType tuba_api_notification_relationship_severance_event_type_id;
		tuba_api_notification_relationship_severance_event_type_id = tuba_api_notification_relationship_severance_event_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_notification_relationship_severance_event_type_id__once, tuba_api_notification_relationship_severance_event_type_id);
	}
	return tuba_api_notification_relationship_severance_event_type_id__once;
}

static void
_vala_tuba_api_notification_relationship_severance_event_get_property (GObject * object,
                                                                       guint property_id,
                                                                       GValue * value,
                                                                       GParamSpec * pspec)
{
	TubaAPINotificationRelationshipSeveranceEvent * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, TubaAPINotificationRelationshipSeveranceEvent);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_KIND_PROPERTY:
		g_value_set_string (value, tuba_api_notification_relationship_severance_event_get_kind (self));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_TARGET_NAME_PROPERTY:
		g_value_set_string (value, tuba_api_notification_relationship_severance_event_get_target_name (self));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_RELATIONSHIPS_COUNT_PROPERTY:
		g_value_set_int64 (value, tuba_api_notification_relationship_severance_event_get_relationships_count (self));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWERS_COUNT_PROPERTY:
		g_value_set_int64 (value, tuba_api_notification_relationship_severance_event_get_followers_count (self));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWING_COUNT_PROPERTY:
		g_value_set_int64 (value, tuba_api_notification_relationship_severance_event_get_following_count (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_notification_relationship_severance_event_set_property (GObject * object,
                                                                       guint property_id,
                                                                       const GValue * value,
                                                                       GParamSpec * pspec)
{
	TubaAPINotificationRelationshipSeveranceEvent * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, TubaAPINotificationRelationshipSeveranceEvent);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_KIND_PROPERTY:
		tuba_api_notification_relationship_severance_event_set_kind (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_TARGET_NAME_PROPERTY:
		tuba_api_notification_relationship_severance_event_set_target_name (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_RELATIONSHIPS_COUNT_PROPERTY:
		tuba_api_notification_relationship_severance_event_set_relationships_count (self, g_value_get_int64 (value));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWERS_COUNT_PROPERTY:
		tuba_api_notification_relationship_severance_event_set_followers_count (self, g_value_get_int64 (value));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_FOLLOWING_COUNT_PROPERTY:
		tuba_api_notification_relationship_severance_event_set_following_count (self, g_value_get_int64 (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_notification_moderation_warning_get_instance_private (TubaAPINotificationModerationWarning* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINotificationModerationWarning_private_offset);
}

TubaAPINotificationModerationWarning*
tuba_api_notification_moderation_warning_construct (GType object_type)
{
	TubaAPINotificationModerationWarning * self = NULL;
	self = (TubaAPINotificationModerationWarning*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINotificationModerationWarning*
tuba_api_notification_moderation_warning_new (void)
{
	return tuba_api_notification_moderation_warning_construct (TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING);
}

const gchar*
tuba_api_notification_moderation_warning_get_id (TubaAPINotificationModerationWarning* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_moderation_warning_set_id (TubaAPINotificationModerationWarning* self,
                                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_moderation_warning_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_moderation_warning_properties[TUBA_API_NOTIFICATION_MODERATION_WARNING_ID_PROPERTY]);
	}
}

static void
tuba_api_notification_moderation_warning_class_init (TubaAPINotificationModerationWarningClass * klass,
                                                     gpointer klass_data)
{
	tuba_api_notification_moderation_warning_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINotificationModerationWarning_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_notification_moderation_warning_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_notification_moderation_warning_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_notification_moderation_warning_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_MODERATION_WARNING_ID_PROPERTY, tuba_api_notification_moderation_warning_properties[TUBA_API_NOTIFICATION_MODERATION_WARNING_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_notification_moderation_warning_instance_init (TubaAPINotificationModerationWarning * self,
                                                        gpointer klass)
{
	self->priv = tuba_api_notification_moderation_warning_get_instance_private (self);
}

static void
tuba_api_notification_moderation_warning_finalize (GObject * obj)
{
	TubaAPINotificationModerationWarning * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING, TubaAPINotificationModerationWarning);
	_g_free0 (self->priv->_id);
	G_OBJECT_CLASS (tuba_api_notification_moderation_warning_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_notification_moderation_warning_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINotificationModerationWarningClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_notification_moderation_warning_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINotificationModerationWarning), 0, (GInstanceInitFunc) tuba_api_notification_moderation_warning_instance_init, NULL };
	GType tuba_api_notification_moderation_warning_type_id;
	tuba_api_notification_moderation_warning_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINotificationModerationWarning", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINotificationModerationWarning_private_offset = g_type_add_instance_private (tuba_api_notification_moderation_warning_type_id, sizeof (TubaAPINotificationModerationWarningPrivate));
	return tuba_api_notification_moderation_warning_type_id;
}

GType
tuba_api_notification_moderation_warning_get_type (void)
{
	static GType tuba_api_notification_moderation_warning_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_notification_moderation_warning_type_id__once)) {
		GType tuba_api_notification_moderation_warning_type_id;
		tuba_api_notification_moderation_warning_type_id = tuba_api_notification_moderation_warning_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_notification_moderation_warning_type_id__once, tuba_api_notification_moderation_warning_type_id);
	}
	return tuba_api_notification_moderation_warning_type_id__once;
}

static void
_vala_tuba_api_notification_moderation_warning_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	TubaAPINotificationModerationWarning * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING, TubaAPINotificationModerationWarning);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_MODERATION_WARNING_ID_PROPERTY:
		g_value_set_string (value, tuba_api_notification_moderation_warning_get_id (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_notification_moderation_warning_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	TubaAPINotificationModerationWarning * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING, TubaAPINotificationModerationWarning);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_MODERATION_WARNING_ID_PROPERTY:
		tuba_api_notification_moderation_warning_set_id (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_notification_class_init (TubaAPINotificationClass * klass,
                                  gpointer klass_data)
{
	tuba_api_notification_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINotification_private_offset);
	((TubaAPINotificationClass *) klass)->to_toast = (void (*) (TubaAPINotification*, TubaInstanceAccount*, gint, GAsyncReadyCallback, gpointer)) tuba_api_notification_real_to_toast;
	((TubaAPINotificationClass *) klass)->to_toast_finish = (GNotification* (*) (TubaAPINotification*, GAsyncResult*)) tuba_api_notification_real_to_toast_finish;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_notification_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_notification_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_notification_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_ID_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_ACCOUNT_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_ACCOUNT_PROPERTY] = g_param_spec_object ("account", "account", "account", TUBA_API_TYPE_ACCOUNT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_KIND_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_KIND_PROPERTY] = g_param_spec_string ("kind", "kind", "kind", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_CREATED_AT_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_CREATED_AT_PROPERTY] = g_param_spec_string ("created-at", "created-at", "created-at", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_STATUS_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_STATUS_PROPERTY] = g_param_spec_object ("status", "status", "status", TUBA_API_TYPE_STATUS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_EMOJI_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_EMOJI_PROPERTY] = g_param_spec_string ("emoji", "emoji", "emoji", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_EMOJI_URL_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_EMOJI_URL_PROPERTY] = g_param_spec_string ("emoji-url", "emoji-url", "emoji-url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_REPORT_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_REPORT_PROPERTY] = g_param_spec_object ("report", "report", "report", TUBA_API_ADMIN_TYPE_REPORT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_MODERATION_WARNING_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_MODERATION_WARNING_PROPERTY] = g_param_spec_object ("moderation-warning", "moderation-warning", "moderation-warning", TUBA_API_NOTIFICATION_TYPE_MODERATION_WARNING, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_GROUP_KEY_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_GROUP_KEY_PROPERTY] = g_param_spec_string ("group-key", "group-key", "group-key", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_COLLECTION_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_COLLECTION_PROPERTY] = g_param_spec_object ("collection", "collection", "collection", TUBA_API_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_EVENT_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_EVENT_PROPERTY] = g_param_spec_object ("event", "event", "event", TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_PROPERTY, tuba_api_notification_properties[TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_PROPERTY] = g_param_spec_object ("relationship-severance-event", "relationship-severance-event", "relationship-severance-event", TUBA_API_NOTIFICATION_TYPE_RELATIONSHIP_SEVERANCE_EVENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_notification_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                        gpointer iface_data)
{
	tuba_api_notification_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->open = (void (*) (TubaWidgetizable*)) tuba_api_notification_real_open;
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_notification_real_to_widget;
}

static void
tuba_api_notification_instance_init (TubaAPINotification * self,
                                     gpointer klass)
{
	self->priv = tuba_api_notification_get_instance_private (self);
	self->priv->_kind = NULL;
	self->priv->_created_at = NULL;
	self->priv->_status = NULL;
	self->priv->_emoji = NULL;
	self->priv->_emoji_url = NULL;
	self->priv->_report = NULL;
	self->priv->_moderation_warning = NULL;
	self->priv->_group_key = NULL;
	self->priv->_collection = NULL;
	self->priv->_event = NULL;
	self->priv->_relationship_severance_event = NULL;
}

static void
tuba_api_notification_finalize (GObject * obj)
{
	TubaAPINotification * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_NOTIFICATION, TubaAPINotification);
	_g_free0 (self->priv->_id);
	_g_object_unref0 (self->priv->_account);
	_g_free0 (self->priv->_kind);
	_g_free0 (self->priv->_created_at);
	_g_object_unref0 (self->priv->_status);
	_g_free0 (self->priv->_emoji);
	_g_free0 (self->priv->_emoji_url);
	_g_object_unref0 (self->priv->_report);
	_g_object_unref0 (self->priv->_moderation_warning);
	_g_free0 (self->priv->_group_key);
	_g_object_unref0 (self->priv->_collection);
	_g_object_unref0 (self->priv->_event);
	_g_object_unref0 (self->priv->_relationship_severance_event);
	G_OBJECT_CLASS (tuba_api_notification_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_notification_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINotificationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_notification_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINotification), 0, (GInstanceInitFunc) tuba_api_notification_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_notification_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_notification_type_id;
	tuba_api_notification_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINotification", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_notification_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPINotification_private_offset = g_type_add_instance_private (tuba_api_notification_type_id, sizeof (TubaAPINotificationPrivate));
	return tuba_api_notification_type_id;
}

GType
tuba_api_notification_get_type (void)
{
	static GType tuba_api_notification_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_notification_type_id__once)) {
		GType tuba_api_notification_type_id;
		tuba_api_notification_type_id = tuba_api_notification_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_notification_type_id__once, tuba_api_notification_type_id);
	}
	return tuba_api_notification_type_id__once;
}

static void
_vala_tuba_api_notification_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	TubaAPINotification * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_NOTIFICATION, TubaAPINotification);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_ID_PROPERTY:
		g_value_set_string (value, tuba_api_notification_get_id (self));
		break;
		case TUBA_API_NOTIFICATION_ACCOUNT_PROPERTY:
		g_value_set_object (value, tuba_api_notification_get_account (self));
		break;
		case TUBA_API_NOTIFICATION_KIND_PROPERTY:
		g_value_set_string (value, tuba_api_notification_get_kind (self));
		break;
		case TUBA_API_NOTIFICATION_CREATED_AT_PROPERTY:
		g_value_set_string (value, tuba_api_notification_get_created_at (self));
		break;
		case TUBA_API_NOTIFICATION_STATUS_PROPERTY:
		g_value_set_object (value, tuba_api_notification_get_status (self));
		break;
		case TUBA_API_NOTIFICATION_EMOJI_PROPERTY:
		g_value_set_string (value, tuba_api_notification_get_emoji (self));
		break;
		case TUBA_API_NOTIFICATION_EMOJI_URL_PROPERTY:
		g_value_set_string (value, tuba_api_notification_get_emoji_url (self));
		break;
		case TUBA_API_NOTIFICATION_REPORT_PROPERTY:
		g_value_set_object (value, tuba_api_notification_get_report (self));
		break;
		case TUBA_API_NOTIFICATION_MODERATION_WARNING_PROPERTY:
		g_value_set_object (value, tuba_api_notification_get_moderation_warning (self));
		break;
		case TUBA_API_NOTIFICATION_GROUP_KEY_PROPERTY:
		g_value_set_string (value, tuba_api_notification_get_group_key (self));
		break;
		case TUBA_API_NOTIFICATION_COLLECTION_PROPERTY:
		g_value_set_object (value, tuba_api_notification_get_collection (self));
		break;
		case TUBA_API_NOTIFICATION_EVENT_PROPERTY:
		g_value_set_object (value, tuba_api_notification_get_event (self));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_PROPERTY:
		g_value_set_object (value, tuba_api_notification_get_relationship_severance_event (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_notification_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec)
{
	TubaAPINotification * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_NOTIFICATION, TubaAPINotification);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_ID_PROPERTY:
		tuba_api_notification_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_ACCOUNT_PROPERTY:
		tuba_api_notification_set_account (self, g_value_get_object (value));
		break;
		case TUBA_API_NOTIFICATION_KIND_PROPERTY:
		tuba_api_notification_set_kind (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_CREATED_AT_PROPERTY:
		tuba_api_notification_set_created_at (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_STATUS_PROPERTY:
		tuba_api_notification_set_status (self, g_value_get_object (value));
		break;
		case TUBA_API_NOTIFICATION_EMOJI_PROPERTY:
		tuba_api_notification_set_emoji (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_EMOJI_URL_PROPERTY:
		tuba_api_notification_set_emoji_url (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_REPORT_PROPERTY:
		tuba_api_notification_set_report (self, g_value_get_object (value));
		break;
		case TUBA_API_NOTIFICATION_MODERATION_WARNING_PROPERTY:
		tuba_api_notification_set_moderation_warning (self, g_value_get_object (value));
		break;
		case TUBA_API_NOTIFICATION_GROUP_KEY_PROPERTY:
		tuba_api_notification_set_group_key (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_COLLECTION_PROPERTY:
		tuba_api_notification_set_collection (self, g_value_get_object (value));
		break;
		case TUBA_API_NOTIFICATION_EVENT_PROPERTY:
		tuba_api_notification_set_event (self, g_value_get_object (value));
		break;
		case TUBA_API_NOTIFICATION_RELATIONSHIP_SEVERANCE_EVENT_PROPERTY:
		tuba_api_notification_set_relationship_severance_event (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

